# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTExportTessellatedEdgesResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'error_enum': 'str',
        'bodies': 'list[BTExportTessellatedEdgesBody]',
        'type_id': 'int',
        'connection_source': 'BTConnection',
        'export_type_name': 'str',
        'unknown_class': 'bool'
    }

    attribute_map = {
        'error_enum': 'errorEnum',
        'bodies': 'bodies',
        'type_id': 'typeId',
        'connection_source': 'connectionSource',
        'export_type_name': 'exportTypeName',
        'unknown_class': 'unknownClass'
    }

    def __init__(self, error_enum=None, bodies=None, type_id=None, connection_source=None, export_type_name=None, unknown_class=None):  # noqa: E501
        """BTExportTessellatedEdgesResponse - a model defined in OpenAPI"""  # noqa: E501

        self._error_enum = None
        self._bodies = None
        self._type_id = None
        self._connection_source = None
        self._export_type_name = None
        self._unknown_class = None
        self.discriminator = None

        if error_enum is not None:
            self.error_enum = error_enum
        if bodies is not None:
            self.bodies = bodies
        if type_id is not None:
            self.type_id = type_id
        if connection_source is not None:
            self.connection_source = connection_source
        if export_type_name is not None:
            self.export_type_name = export_type_name
        if unknown_class is not None:
            self.unknown_class = unknown_class

    @property
    def error_enum(self):
        """Gets the error_enum of this BTExportTessellatedEdgesResponse.  # noqa: E501


        :return: The error_enum of this BTExportTessellatedEdgesResponse.  # noqa: E501
        :rtype: str
        """
        return self._error_enum

    @error_enum.setter
    def error_enum(self, error_enum):
        """Sets the error_enum of this BTExportTessellatedEdgesResponse.


        :param error_enum: The error_enum of this BTExportTessellatedEdgesResponse.  # noqa: E501
        :type: str
        """
        allowed_values = ["NO_ERROR", "UNKNOWN_OPERATION", "TOO_MANY_ENTITIES_SELECTED", "POINTS_COINCIDENT", "NO_TRANSLATION_DIRECTION", "NO_ROTATION_AXIS", "NO_TANGENT_PLANE", "NO_TANGENT_LINE", "INVALID_INPUT", "CANNOT_RESOLVE_ENTITIES", "CANNOT_EVALUATE_VERTEX", "CANNOT_RESOLVE_PLANE", "CANNOT_COMPUTE_BBOX", "CANNOT_BE_EMPTY", "CACHE_WRITE_FAILED", "CACHE_READ_FAILED", "HLR_FAILED", "BAD_GEOMETRY", "INVALID_RESULT", "MISSING_EXT_REF", "READ_FAILED", "WRITE_FAILED", "WRONG_TYPE", "TANGENT_PROPAGATION_FAILED", "REGEN_ERROR", "COULD_NOT_COMPUTE_TRANSFORM", "MATE_INVALID_MATE", "MATECONNECTOR_INVALID_MATE", "MATE_TWO_MATECONNECTORS_NEEDED", "MATECONNECTORS_ON_SAME_OCCURRENCE", "MATE_OVERDEFINED", "MATE_INCONSISTENT", "BOOLEAN_NEED_ONE_SOLID", "BOOLEAN_INVALID", "BOOLEAN_INTERSECT_FAIL", "BOOLEAN_SAME_INPUT", "BOOLEAN_BAD_INPUT", "BOOLEAN_UNION_NO_OP", "BOOLEAN_INTERSECT_NO_OP", "BOOLEAN_SUBTRACT_NO_OP", "CPLANE_INPUT_MIDPLANE", "CPLANE_INPUT_OFFSET_PLANE", "CPLANE_INPUT_POINT_PLANE", "CPLANE_INPUT_LINE_ANGLE", "CPLANE_INPUT_POINT_LINE", "CPLANE_INPUT_THREE_POINT", "CPLANE_FAILED", "DRAFT_NO_NEUTRAL_PLANE", "DRAFT_NO_DRAFT_FACE", "DRAFT_FAILED", "EXTRUDE_INVALID_REF_FACE", "EXTRUDE_INVALID_REF_SURFACE", "EXTRUDE_FAILED", "EXTRUDE_NO_DIRECTION", "EXTRUDE_INVALID_ENTITIES", "PATTERN_INPUT_TOO_MANY_INSTANCES", "PATTERN_INPUT_TOO_FEW_INSTANCES", "PATTERN_FACE_FAILED", "PATTERN_NOT_ON_BODY", "PATTERN_BODY_FAILED", "TRANSFORM_TRANSLATE_INPUT", "TRANSFORM_TRANSLATE_BY_DISTANCE_INPUT", "TRANSFORM_FAILED", "SHELL_FAILED", "EDGEBLEND_SMOOTH", "EDGEBLEND_FAILED", "DIRECT_EDIT_WRONG_CONCENTRIC", "DIRECT_EDIT_WRONG_EQ_RADIUS", "DIRECT_EDIT_NO_FILLET_FACES", "DIRECT_EDIT_NO_OFFSET", "DIRECT_EDIT_CONSTRAIN_FACE_FAILED", "DIRECT_EDIT_REPLACE_FACE_FAILED", "DIRECT_EDIT_DELETE_FACE_FAILED", "DIRECT_EDIT_MODIFY_FILLET_FAILED", "DIRECT_EDIT_MODIFY_FACE_FAILED", "DIRECT_EDIT_MOVE_FACE_FAILED", "DIRECT_EDIT_OFFSET_FACE_FAILED", "IMPORT_PART_FAILED", "IMPORT_ASSEMBLY_FAILED", "IMPRINT_FAILED", "REVOLVE_FAILED", "REVOLVE_2ND_DIR_FAILED", "REVOLVE_NOT_PLANAR", "REVOLVE_PERPENDICULAR", "REVOLVE_INVALID_ENTITIES", "SPLIT_FAILED", "SPLIT_INVALID_INPUT", "SWEEP_INVALID_PATH", "SWEEP_FAILED", "SWEEP_PATH_FAILED", "SWEEP_PROFILE_FAILED", "WIRE_CREATION_FAILED", "SKETCH_NO_PLANE", "SKETCH_INPUT_INVALID", "SKETCH_NOT_ACTIVE", "SKETCH_SOLVER_NOT_INITIALIZED", "SKETCH_EVALUATION_FAILED", "SKETCH_MODIFICATION_FAILED", "SKETCH_UPDATE_FAILED", "SKETCH_SOLVE_FAILED", "SKETCH_ADD_CONSTRAINT_FAILED", "SKETCH_ADD_DIMENSION_FAILED", "SKETCH_POSITION_DIMENSION_FAILED", "SKETCH_CONSTRAINT_NEEDS_SKETCH_ENTITY", "SKETCH_CONSTRAINT_UNKNOWN", "SKETCH_MISSING_ENTITY", "SKETCH_FILLET_INVALID_POINT", "SKETCH_FILLET_PARALLEL", "SKETCH_FILLET_FAIL", "SKETCH_USE_FAILED", "SKETCH_USE_PARTIAL", "SKETCH_SPLINE_FAILED", "SKETCH_BAD_SPLINE", "SKETCH_DRAG_ERROR", "SKETCH_PROJ_FAILED", "SKETCH_PROJ_PARTIAL", "SKETCH_TANGENT_ARC_FAILED", "SKETCH_TANGENT_NOT_FOUND", "SKETCH_OFFSET_FAILED", "SKETCH_OFFSET_DISTANCE", "SKETCH_TRIM_FAILED", "SKETCH_INFERENCE_FAILED", "SKETCH_MODIFY_DIM_FAILED", "SKETCH_DRAG_NO_SKETCH", "SKETCH_INFER_DIM_FAILED", "SKETCH_DELETE_PTS_FAILED", "SKETCH_DELETE_FAILED", "SKETCH_ARC_FAILED", "SKETCH_LINE_FAILED", "SKETCH_CIRCLE_FAILED", "SKETCH_RECTANGLE_FAILED", "SKETCH_TANGENT_ARC_INVALID_START", "SKETCH_CONSTRUCTION_POINT_FAILED", "SYS_INTERNAL_DESERIALIZATION", "SYS_SERVER_EXCEPTION", "SYS_ERROR_REGEN", "SYS_ERROR_MESSAGING", "CANNOT_RESOLVE_ELEMENT", "NOTHING_SELECTED", "SKETCH_ANGLE_TWO_LINES", "SKETCH_DIMENSION_DIFF_ENTITIES", "SKETCH_CONSTRAINT_DIFF_ENTITIES", "SKETCH_CONSTRAINT_TWO_ENTITIES", "SKETCH_DIMENSION_TWO_ENTITIES", "SKETCH_COINCIDENT_FAILED", "SKETCH_COINCIDENT_INPUT_ERROR", "SKETCH_COINCIDENT_DIFF_POINTS", "SKETCH_CONCENTRIC_INPUT_ERROR", "SKETCH_CONCENTRIC_FAILED", "SKETCH_EQUAL_INPUT_ERROR", "SKETCH_EQUAL_NO_ENDS", "SKETCH_EQUAL_FAILED", "SKETCH_FIX_ONE_ENT", "SKETCH_FIX_FAILED", "SKETCH_DIR_INTERNAL", "SKETCH_DIR_INPUT", "SKETCH_HORIZONTAL_FAILED", "SKETCH_VERTICAL_FAILED", "SKETCH_OFFSET_CONSTRAINT_FAILED", "SKETCH_PARALLEL_CONSTRAINT_FAILED", "SKETCH_PARALLEL_INPUT_ERROR", "SKETCH_DIMENSION_INPUT_ERROR", "SKETCH_DIMENSION_DIST_ERROR", "SKETCH_DIMENSION_FAILED", "SKETCH_NORMAL_NEED_LINE", "SKETCH_NORMAL_INPUT_ERROR", "SKETCH_NORMAL_INPUT_NEEDED", "SKETCH_CANNOT_SPLIT_INTO_GROUPS", "SKETCH_OFFSET_BAD_PAIR", "SKETCH_OFFSET_INPUT_ERROR", "SKETCH_MIDPOINT_INPUT_ERROR", "SKETCH_MIDPOINT_NEED_POINT", "SKETCH_MIDPOINT_NEED_DIFF_POINT", "SKETCH_MIDPOINT_MISSING_ENDS", "SKETCH_MIDPOINT_MISSING_PTS", "SKETCH_MIDPOINT_NO_INTERNAL_LINE", "SKETCH_MIDPOINT_NO_COINCIDENT", "SKETCH_MIDPOINT_FAILED", "SKETCH_PERPENDICULAR_INPUT_ERROR", "SKETCH_PERPENDICULAR_FAILED", "SKETCH_POINT_LINE_ONLY", "SKETCH_PROJECTION_UNKNOWN", "SKETCH_PROJECTION_FAILED", "SKETCH_SIL_PROJECTION_INPUT_ERROR", "SKETCH_SIL_PROJECTION_MISSING_POINT", "SKETCH_LENGTH_DIM_INPUT_ERROR", "SKETCH_LENGTH_DIM_MISSING_ENDS", "SKETCH_LENGTH_DIM_NOT_FOUND", "SKETCH_LENGTH_DIM_FAILED", "SKETCH_RADIUS_INPUT_ERROR", "SKETCH_RADIUS_DIM_FAILED", "SKETCH_TANGENT_INPUT_ERROR", "SKETCH_TANGENT_FAILED", "PART_QUERY_FAILED", "PART_QUERY_MULTI", "MATECONNECTOR_QUERY_FAILED", "MATECONNECTOR_QUERY_ORIGIN_FAILED", "MATECONNECTOR_QUERY_AXIS_FAILED", "MATECONNECTOR_QUERY_CSYS_FAILED", "ASSEMBLY_INSERT_WILL_CAUSE_CYCLES", "SKETCH_MIRROR_NEED_VALID_MIRROR_LINE", "SKETCH_MIRROR_NEED_ENTITIES_TO_MIRROR", "SKETCH_MIRROR_CONSTRAINT_FAILED", "SKETCH_MIRROR_FAILED", "SELF_INTERSECTING_CURVE_SELECTED", "SWEEP_START_NOT_ON_PROFILE", "PATTERN_DIRECTIONS_PARALLEL", "MATE_OCCURRENCE_NOT_VALID", "MATE_WITHIN_SAME_GROUP", "EXPORT_ASSEMBLY_UNKNOWN_NODE_TYPE", "EXPORT_ASSEMBLY_CREATE_INSTANCE_FAILED", "EXPORT_PARTS_AS_XTS_NOT_A_BODY", "EXPORT_PARTS_AS_XTS_FAILED_TO_WRITE_XT", "MATECONNECTOR_OWNER_PART_NOT_RESOLVED", "WIRE_CREATION_PARTIAL_FAILURE", "SERVER_IS_IN_INVALID_STATE", "SKETCH_EXTEND_FAILED", "FOLLOW_CYCLE_ERROR", "SKETCH_FILLET_INVALID_RADIUS", "SKETCH_CONSTRAINT_COINCIDENT_TWO_ENTITIES", "SKETCH_CONSTRAINT_CONCENTRIC_TWO_ENTITIES", "SKETCH_CONSTRAINT_EQUAL_TWO_ENTITIES", "SKETCH_CONSTRAINT_MIDPOINT_TWO_ENTITIES", "EXTRUDE_NO_SELECTED_REGION", "EXTRUDE_NO_REGION_IN_SKETCH", "DELETE_SELECT_PARTS", "COPY_SELECT_PARTS", "SPLIT_NO_CHANGE", "MIRROR_NO_PLANE", "MIRROR_SELECT_PARTS", "PATTERN_CIRCULAR_NO_AXIS", "PATTERN_SELECT_FACES", "PATTERN_SELECT_PARTS", "PATTERN_LINEAR_NO_DIR", "SHELL_SELECT_FACES", "DRAFT_SELECT_NEUTRAL", "DRAFT_SELECT_FACES", "CHAMFER_SELECT_EDGES", "FILLET_SELECT_EDGES", "EXTRUDE_SURF_NO_CURVE", "EXTRUDE_SELECT_TERMINATING_BODY", "EXTRUDE_SELECT_TERMINATING_SURFACE", "DIRECT_EDIT_SELECT_ANCHOR", "REVOLVE_SURF_NO_CURVE", "REVOLVE_SELECT_FACES", "REVOLVE_SELECT_AXIS", "SWEEP_SELECT_PROFILE", "SWEEP_SELECT_PATH", "DIRECT_EDIT_DELETE_SELECT_FACES", "DIRECT_EDIT_MODIFY_FILLET_SELECT", "DIRECT_EDIT_MODIFY_FACE_SELECT", "DIRECT_EDIT_REPLACE_FACE_SELECT", "DIRECT_EDIT_OFFSET_FACE_SELECT", "DIRECT_EDIT_MOVE_FACE_SELECT", "SELECT_MATECONNECTOR", "OVERDEFINED_ASSEMBLY", "PART_STUDIO_UPGRADE_SUCCESSFUL", "PART_STUDIO_UPGRADE_FAILED", "PART_STUDIO_UPGRADE_NONE", "MATE_GROUP_OCCURRENCES_UNRESOLVED", "SWEEP_SURF_NO_CURVE_PROFILE", "MATE_RESET_HAD_NO_EFFECT", "MATECONNECTOR_MULTIPLE_OCCURRENCES", "MATECONNECTOR_OCCURRENCE_NOT_RESOLVED", "ELEMENT_REFERENCE_CYCLE_DETECTED", "MATE_OVERDEFINES_ASSEMBLY", "MATE_CANNOT_RESOLVE_CONNECTORS", "SKETCH_EXCEEDS_BOUNDS", "SWEEP_SELF_INT", "SKETCH_UNSOLVABLE_CONSTRAINT", "RESTRUCTURE_INVALID_SOURCE_OR_TARGET", "CPLANE_INPUT_CURVE_POINT", "TRANSFORM_OCCURRENCES_HAD_NO_EFFECT", "HELIX_FAILED", "HELIX_INPUT_CONE", "RENDERER_NOT_AVAILABLE", "RENDERER_FAILED_TO_RENDER", "EXPRESSION_FAILED_VALIDATION", "VERSION_MISMATCH_ERROR", "EXTRUDE_UPTO_NEXT_NO_DIVISION", "MATE_BETWEEN_FIXED_OCCURRENCES", "THICKEN_SELECT_ENTITIES", "THICKEN_FAILED", "WORKSPACE_UPGRADE_SUCCESSFUL", "WORKSPACE_UPGRADE_FAILED", "WORKSPACE_UPGRADE_NONE", "SKETCH_CIRCULAR_PATTERN_FAILED", "DIRECT_EDIT_ALL_FILLET_FACES_SELECTED", "DIRECT_EDIT_FAILED_TO_IDENTIFY_FILLETS", "PARASOLID_IMPORT_FAILED", "FOLLOW_LEADER_HAS_NO_FUNCTIONALITY_ERROR", "MIRROR_SELECT_FACES", "RELATION_INVALID_RELATION", "RELATION_INVALID_MATE", "GEAR_RELATION_INVALID_MATE_TYPES", "SCREW_RELATION_INVALID_MATE_TYPES", "RACK_RELATION_INVALID_MATE_TYPES", "ROLLING_RELATION_INVALID_MATE_TYPES", "LINEAR_RELATION_INVALID_MATE_TYPES", "RELATION_OVERDEFINED", "RELATION_INCONSISTENT", "RELATION_SAME_OCCURRENCES", "SKETCH_SPLIT_FAILED", "SKETCH_CONSTRAINT_PIERCE_TWO_ENTITIES", "SKETCH_PIERCE_FAILED", "MIRROR_FACE_FAILED", "MIRROR_BODY_FAILED", "SKETCH_CANNOT_PIERCE_WITH_PLANE", "WITH_SUPPORT_CODE", "FILLET_FAIL_SMOOTH", "FILLET_FAILED", "CHAMFER_FAIL_SMOOTH", "CHAMFER_FAILED", "BOOLEAN_OFFSET_NO_FACES", "MATE_OCCURRENCE_SUPPRESSED", "MATECONNECTOR_OCCURRENCE_SUPPRESSED", "SKETCH_SPLINE_NEW_POINTS_TOO_CLOSE", "SKETCH_SPLINE_CANNOT_DELETE_ENDPOINTS", "SKETCH_SPLINE_POINT_TO_DELETE_NOT_FOUND", "ASSEMBLY_INSERT_FAILED", "SKETCH_PATTERN_UNKNOWN_FAILURE", "SKETCH_PATTERN_TOO_LARGE", "SKETCH_LINEAR_PATTERN_ZERO_LENGTH", "SKETCH_LINEAR_PATTERN_PARALLEL_DIRECTIONS", "SKETCH_CIRCULAR_PATTERN_ZERO_ANGLE", "SKETCH_ELLIPSE_FAILED", "SKETCH_ELLIPSE_FAILED_TOO_SMALL", "DELETE_PARTS_FAILED", "DELETE_PARTS_PARTIAL", "SKETCH_ELLIPSE_RADIUS_INPUT_ERROR", "QUADRANT_CONSTRAINT_INPUT", "SKETCH_QUADRANT_FAILED", "SKETCH_SPLINE_TOO_FEW_POINTS", "SKETCH_SPLINE_NOT_INTERPOLATED_SPLINE", "SKETCH_SPLINE_POINTS_NOT_DELETED", "SKETCH_TEXT_RECTANGLE_FAILED", "IMPORT_DERIVED_NO_PARTS", "LOFT_SELECT_PROFILES", "LOFT_PROFILE_SINGLE_FACE", "LOFT_PROFILE_SOLID", "LOFT_PROFILE_POINT", "LOFT_PROFILE_FAILED", "LOFT_SELECT_GUIDES", "LOFT_GUIDE_FAILED", "LOFT_PERIODIC_ERROR", "LOFT_GUIDE_POINT_INTERSECTION", "LOFT_GUIDE_PROFILE_INTERSECTION", "LOFT_VERTEX_MATCHING", "LOFT_DIRECTION_ERROR", "LOFT_PROFILE_ALIGNMENT", "LOFT_GUIDE_ALIGNMENT", "LOFT_VERTEX_ADDITIONS", "LOFT_FAILED", "LOFT_INVALID", "LOFT_ALIGNMENT_INFO", "LOFT_VERTEX_NOT_ON_PROFILE", "LOFT_PROFILE_NO_INNER_LOOPS", "LOFT_TWO_PROFILES", "CANNOT_OFFSET_ELLIPSE", "SKETCH_MIRROR_NEEDS_LINE_AND_TWO_OTHERS", "SKETCH_POLYGON_BAD_SIDE_COUNT", "SKETCH_DIRECTIONAL_GROUP_INPUT", "NAMED_VIEWS_DUPLICATE_NAME", "SILHOUETTE_USE_FAILED", "PASTE_SKETCH_METRICS_FAILURE", "PASTE_SKETCH_LIBRARY_MISMATCH", "PASTE_SKETCH_CLIPBOARD_EMPTY", "SKETCH_MIRROR_OFFSET_SPLINE", "SKETCH_MIRROR_CURVE_POINT", "LOFT_PERIODIC_GUIDE_ERROR", "SHELL_SELECT_PARTS", "RELATION_MATE_DOES_NOT_EXIST", "RELATION_MATE_IS_SUPPRESSED", "VARIABLE_NAME_INVALID", "LOFT_GUIDE_INFO", "HOLE_NO_POINTS", "HOLE_FAIL_BBOX", "HOLE_EMPTY_SCOPE", "HOLE_NO_HITS", "WITH_EXTRA_DATA", "HOLE_DISJOINT", "SKETCH_INSERT_DWG_CONVERSION_FAILURE", "HOLE_CBORE_TOO_SMALL", "HOLE_CBORE_TOO_DEEP", "HOLE_CSINK_TOO_SMALL", "HOLE_CSINK_TOO_DEEP", "SWEEP_PATH_NO_CONSTRUCTION", "SKETCH_IMAGE_RECTANGLE_FAILED", "ASSEMBLY_REPLICATE_NO_VALID_TARGET", "ASSEMBLY_REPLICATE_NO_MATCHING_TARGET", "LOFT_SHAPE_CONTROL_FAILED", "LOFT_START_CONDITIONS_FAILED", "LOFT_END_CONDITIONS_FAILED", "LOFT_NO_FACE_FOR_START_CLAMP", "LOFT_NO_FACE_FOR_END_CLAMP", "LOFT_NO_PLANE_FOR_START_CLAMP", "LOFT_NO_PLANE_FOR_END_CLAMP", "LOFT_NO_CLAMPS_ON_POINT_PROFILE", "EXPORT_NOT_IMPLEMENTED", "SKETCH_POLYGON_ZERO_RADIUS_FAIL", "DRAWING_FAILED_TO_RESOLVE_VIEW_REFERENCE", "DRAWING_PARTSTUDIO_EMPTY_AFTER_SECTION_CUT", "DRAWING_ASSEMBLY_DOES_NOT_CONTAIN_VISIBLE_INSTANCES", "DRAWING_ASSEMBLY_EMPTY_AFTER_SECTION_CUT", "DRAWING_VIEW_GENERATION_FAILED", "SKETCH_SLOT_FAILURE", "SKETCH_SLOT_PARTIAL_FAILURE", "NO_UNIT", "RESTRUCTURE_INVALID_SOURCE", "RESTRUCTURE_INVALID_TARGET", "MATE_MIN_MAX_LIMIT_VIOLATION", "REST_ASSEMBLY_GET_DOCUMENT_FAILED", "REST_ASSEMBLY_UNKNOWN_INSERTABLE_TYPE", "REST_ASSEMBLY_SETUP_EXCEPTION", "REST_ASSEMBLY_BEGIN_OPERATION_FAILED", "REST_ASSEMBLY_INSERT_INSTANCE_FAILED", "REST_ASSEMBLY_COMMIT_OPERATION_FAILED", "REST_ASSEMBLY_CLOSE_CLIENT_FAILED", "REST_ASSEMBLY_NULL_OCCURRENCES", "REST_ASSEMBLY_EMPTY_OCCURRENCE", "REST_ASSEMBLY_TRANSFORM_WRONG_SIZE", "ASSEMBLY_EMPTY_OCCURRENCE_LIST", "ASSEMBLY_NULL_TRANSFORM", "ASSEMBLY_TRANSFORM_NOT_RIGID", "ASSEMBLY_CANNOT_TRANSFORM_FIXED_OCCURRENCE", "ASSEMBLY_TRANSFORM_FAILED", "ASSEMBLY_OCCURRENCE_NOT_FOUND", "ASSEMBLY_REPLICATE_MULTIPLE_VALID_TARGET", "ASSEMBLY_REPLICATE_NO_TARGET_SELECTED", "CPLANE_INPUT_LINE_ANGLE2", "CPLANE_DEGENERATE_SELECTION", "CPLANE_SELECT_LINE_ANGLE_REFERENCE", "ASSEMBLY_REPLICATE_INVALID_SEED_INSTANCE", "CANNOT_USE_VARIABLES_IN_SKETCH_PATTERNS", "SKETCH_MIRROR_OFFSET_ELLIPSE", "EXTERNAL_REFERENCE_FAILED_TO_CREATE", "SPLIT_FACE_NO_CHANGE", "SKETCH_INTERSECTION_FAILED", "SKETCH_INTERSECTION_MULTIPLE_FAILED", "SKETCH_INTERSECTION_PARTIAL_FAILED", "FEATURE_ID_IN_PATH_DOES_NOT_MATCH_BODY", "FEATURE_NOT_FOUND", "FEATURE_DOES_NOT_MATCH", "FEATURE_HAS_INVALID_TYPE", "FEATURE_DOES_NOT_MATCH_ITS_FEATURE_SPEC", "FEATURE_BAD_SERIALIZATION_VERSION", "FEATURE_WRONG_SERIALIZATION_VERSION", "FEATURE_INVALID_ROLLBACK_INDEX", "FEATURE_ERROR_IN_INPUT", "FEATURE_CONCURRENCY_ERROR", "FEATURE_CHANGE_BREAKS_MODEL", "FEATURE_NODE_IDS_INVALID", "ROLLBACK_INDEX_INVALID", "FEATURE_NO_SOLIDS", "SKETCH_EXTERNAL_GEOMETRY_MISMATCH", "HOLE_EXCEEDS_MAX_LOCATIONS", "SKETCH_TEXT_IS_EMPTY", "SKETCH_INSERT_DWG_MAX_ENTITIES_EXCEEDED", "HOLE_TAP_DIA_TOO_LARGE", "ASSEMBLY_EMPTY_BODY", "SIMPLIFY_BODY_FAILED", "INVALID_VIEW_NAME", "PATTERN_SELECT_FEATURES", "MIRROR_SELECT_FEATURES", "PATTERN_FEATURE_FAILED", "SKETCH_TRANSFORM_FAILED", "TANGENT_MATE_TWO_ENTITIES_NEEDED", "HOLE_CANNOT_DETERMINE_LAST_BODY", "RESTRUCTURE_CANNOT_MODIFY_SAVED_VERSION", "REST_ASSEMBLY_EXTERNAL_REFERENCE_REQUIRES_VERSION", "REST_ASSEMBLY_EXTERNAL_REFERENCE_DISALLOWS_MICROVERSION", "REST_ASSEMBLY_VERSION_SUPPORTED_ONLY_FOR_EXTERNAL_REFERENCES", "SWEEP_BAD_LOCK_FACES", "SKETCH_TEXT_CANNOT_BE_CONSTRUCTION", "CUSTOM_ERROR", "BEND_BAD_CONFIGURATION", "BEND_WRONG_NUMBER_OF_ENTITIES", "BEND_BAD_CURVES", "BEND_GENERAL_ERROR", "BEND_EDGE_NO_EDGES", "BEND_EDGE_NO_SEED_ENTITY", "EXTEND_SHEET_BODY_NO_BODY", "EXTRACT_SURFACE_NO_FACES", "FLATTEN_NO_EDGES", "FLATTEN_NO_FACES", "FOLD_NO_BODIES", "BEND_PREP_NO_FACES", "BEND_PREP_NO_BODIES", "BEND_PREP_ERROR_FINDING_EDGE_LOCATIONS", "BEND_PREP_ERROR_IMPRINTING_EDGES", "ASSEMBLY_ANIMATE_MATE_START_AFTER_END", "ASSEMBLY_ANIMATE_NO_MATE", "ASSEMBLY_ANIMATE_MATE_SUPPRESSED", "TANGENT_MATE_GEOMETRY_NOT_SUPPORTED", "SKETCH_DIMENSION_INFINITY", "BOLEAN_INPUTS_NOT_SOLID", "FACE_IS_NOT_RECTANGLE", "HOLE_DESTROY_SOLID", "HELIX_INPUT_CIRCLE", "IMPORT_SCALING_NON_MESH_DATA", "EVALUATE_FACE_TANGENT_FOR_MESHES", "CANNOT_COMPUTE_CENTROID", "CANNOT_EVALUATE_DIMENSION", "CANNOT_IMPORT_MESH", "SKETCH_ELLIPSE_ZERO_AXIS", "TRANSFORM_SCALE_UNIFORMLY", "TRANSFORM_MATE_CONNECTORS", "ASSEMBLY_WRONG_ELEMENT_TYPE", "ASSEMBLY_ELEMENT_NOT_FOUND", "SHEET_METAL_TABLE_UNKNOWN_ERROR", "SHEET_METAL_TABLE_REGEN_ERROR", "SHEET_METAL_TABLE_READ_ONLY", "ASSEMBLY_PATTERN_INVALID_TYPE", "ASSEMBLY_PATTERN_DIRECTION_ERROR", "ASSEMBLY_PATTERN_NONPOSITIVE_LINEAR_DISTANCE", "ASSEMBLY_PATTERN_NONPOSITIVE_ANGLE", "ASSEMBLY_PATTERN_INVALID_SEED", "ASSEMBLY_PATTERN_INVALID_REFERENCE_MATE_CONNECTOR", "RESTORE_FEATURE_FAILED", "FACES_NOT_OWNED_BY_PARTS", "EDGES_NOT_OWNED_BY_PARTS", "SHEET_METAL_REBUILD_ERROR", "SHEET_METAL_INPUT_BODY_SHOULD_NOT_BE_SHEET_METAL", "SHEET_METAL_CANNOT_RECOGNIZE_PARTS", "SHEET_METAL_CANNOT_THICKEN", "SHEET_METAL_CONVERT_PLANE", "ASSEMBLY_PATTERN_AXIS_ERROR", "RIB_NO_PROFILES", "RIB_NO_PARTS", "RIB_PROFILE_FAILED", "RIB_BODY_FAILED", "RIB_NO_INTERSECTIONS", "RIB_MERGE_FAILED", "ASSEMBLY_NAMED_POSITIONS_SAVE_FAILED", "ASSEMBLY_NAMED_POSITIONS_LOAD_FAILED", "ASSEMBLY_NAMED_POSITIONS_NO_MATES_TO_SAVE", "ASSEMBLY_NAMED_POSITIONS_POSITION_NOT_FOUND", "SPHERE_FAILED", "ASSEMBLY_PATTERN_NOT_SUPPORTED", "ASSEMBLY_NAMED_POSITIONS_PARTIAL_LOAD_FAILURE", "ASSEMBLY_NAMED_POSITIONS_LOAD_SUCCEEDED_WITH_EXTRA_MATES", "ASSEMBLY_NAMED_POSITIONS_SAVED_MATE_NOT_FOUND_ON_LOAD", "SHEET_METAL_SINGLE_MODEL_NEEDED", "SHEET_METAL_ACTIVE_JOIN_NEEDED", "INSTANCE_QUERY_FAILED", "SHEET_METAL_ACTIVE_EDGE_NEEDED", "SHEET_METAL_FLANGE_NO_EDGES", "MESH_NOT_SUPPORTED", "SHEET_METAL_PARTS_PROHIBITED", "VARIABLE_CANNOT_EVALUATE", "DRAWING_ASSEMBLY_INVALID_SECTION_CUT", "DRAWING_PARTSTUDIO_INVALID_SECTION_CUT", "SHEET_METAL_COULD_NOT_UNFOLD", "PARAMETER_OUT_OF_RANGE", "SHEET_METAL_NO_0_ANGLE_BEND", "SHEET_METAL_FLAT_RIP_NO_EDIT", "SHEET_METAL_CANT_CHANGE_TO_FLAT", "PARAMETER_PRECONDITION_FAILED", "PARAMETER_SYNTAX_ERROR", "SHEET_METAL_CAN_ONLY_REMOVE", "SHEET_METAL_CAN_ONLY_SUBTRACT", "REST_ASSEMBLY_INVALID_FEATURE", "REST_ASSEMBLY_INVALID_BODY_TYPE", "PARTING_OUT_TARGET_READONLY", "SHEET_METAL_MULTI_SM_DEFAULT_RADIUS", "SHEET_METAL_FLANGE_FAIL_ALIGNMENT", "SHEET_METAL_FLANGE_FAIL_UP_TO", "SHEET_METAL_FLANGE_FAIL_UP_TO_ENTITY", "SHEET_METAL_FLANGE_FAIL", "SHEET_METAL_FLANGE_FAIL_LIMIT_OPP_FLANGE", "CANT_SPLIT_SHEET_METAL_BEND_FACE", "IN_CONTEXT_INSTANCE_INVALID_TARGET", "SHEET_METAL_SELF_INTERSECTING_MODEL", "SHEET_METAL_SELF_INTERSECTING_FLAT", "SHEET_METAL_NON_90_BUTT", "SHEET_METAL_RIP_STYLE_ERROR", "CANNOT_USE_MATECONNECTORS_IN_PATTERN", "CANNOT_COPY_MATECONNECTORS", "SHEET_METAL_CAN_ONLY_OFFSET", "MODIFIABLE_ENTITY_ONLY", "IN_CONTEXT_UPDATE_DELETED_ASSEMBLY", "IN_CONTEXT_UPDATE_EMPTY_INSTANCE", "IN_CONTEXT_UPDATE_INVALID_SOURCE", "IN_CONTEXT_UPDATE_INVALID_TARGET", "SHEET_METAL_NO_FEATURE_PATTERN", "CUSTOM_FEATURE_DEFINITION_NOT_FOUND", "SHEET_METAL_START_SELECT_BENDS", "SHEET_METAL_END_DONE", "PATH_EDGES_NOT_CONTINUOUS", "SHEET_METAL_RIP_FAIL_INTERNAL_EDGE", "SHEET_METAL_RIP_FAIL", "SHEET_METAL_RIP_MULTI_BODY", "SHEET_METAL_RIP_FAIL_NON_PLANAR", "PATTERN_CURVE_NO_EDGES", "SHEET_METAL_RIP_NO_CORNER", "SHEET_METAL_RIP_EVEN", "SHEET_METAL_RIP_WALL_NOT_FOUND", "SHEET_METAL_RIP_SAME_VERTEX", "SHEET_METAL_RIP_NEED_MORE_VERTICES", "SHEET_METAL_MAKE_JOINT_FAIL", "CURVE_PATTERN_START_OFF_PATH", "PART_LOAD_FAILED", "SHEET_METAL_MOVE_NOT_PLANAR", "SHEET_METAL_JOINT_FAIL_ADJACENT_FACES", "WRONG_PARASOLID_VERSION", "SHEET_METAL_SINGLE_MODEL_NEEDED_EDGES", "REST_ASSEMBLY_MISSING_INSTANCE_DOCUMENT_ID", "REST_ASSEMBLY_MISSING_INSTANCE_ELEMENT_ID", "FACE_CLASH", "CURVE_PATTERN_START_OFF_CLOSED_PATH", "SHEET_METAL_CUT_JOINT", "EXPORT_STL_NO_PARTS", "INPUT_NAME_TOO_LONG", "IMPORT_BODY_FAILED_CHECK", "DERIVED_BODIES_HAVE_FAULTS", "SHEET_METAL_BLOCKED_PATTERN", "SHEET_METAL_FLANGE_INTERNAL", "SHEET_METAL_TOO_THICK", "SHEET_METAL_BEND_END_NOT_A_CORNER", "SHEET_METAL_NOT_A_CLOSED_CORNER", "SHEET_METAL_CORNER_NOT_A_BEND_END", "RIB_ONLY_OPEN_PROFILES", "TAB_NO_LONGER_EXISTS", "CLINE_FAILED", "ILLEGAL_MODIFICATION", "ASSEMBLY_MATE_VALUE_SET_FAILED", "EXTRUDE_OFFSET_TOO_DEEP", "SHEET_METAL_CANNOT_MOVE_BEND_EDGE", "UP_TO_FACE_NOT_PARALLEL", "TRANSLATION_FACE_NOT_PLANAR", "MOVE_FACE_NO_INTERSECTION", "SWEEP_PATH_PROFILE_NO_INTERSECTION", "DIRECT_EDIT_MOVE_FACE_CREATE_SELECT", "SHEET_METAL_THICKEN_IN_CONTEXT_INFO", "CANNOT_DELETE_RHO_DIMENSION", "INVALID_RHO", "SKETCH_RHO_DIM_NOT_FOUND", "SKETCH_CONIC_FAILED", "TAB_NAME_TOO_LONG", "DIRECT_EDIT_DELETE_FACE_ALL_FACES", "SHEET_METAL_CORNER_BREAK_FAILED", "BOOLEAN_NO_TARGET_SURFACE", "BAD_BSPLINECURVE_DEFINITION", "REQUIRE_3D_BSPLINECURVE_DATA", "PERIODIC_BSPLINECURVE_NOT_CLOSED", "PERIODIC_BSPLINECURVE_NOT_SMOOTH", "RATIONAL_BSPLINECURVE_WEIGHT_NEGATIVE", "BSPLINECURVE_NOT_G1", "BRIDGING_CURVE_VERTEX_BOTH_SIDES", "BRIDGING_CURVE_ONE_EDGE_EACH_SIDE", "BRIDGING_CURVE_VERTEX_AT_END_OF_EDGE", "PROJECT_CURVES_PARALLEL_PLANES", "PROJECT_CURVES_DIFFERENT_SKETCHES", "SHEET_METAL_SELECT_PART", "VARIABLE_NOT_FOUND", "CANNOT_EDIT_FIXED_CONIC", "EXTRACT_WIRES_OVERLAPPING_EDGES", "EXTRACT_WIRES_NON_MANIFOLD", "EXTRACT_WIRES_NEEDS_EDGES", "SPLINE_TWO_POINTS", "CLOSED_SPLINE_THREE_POINTS", "TANGENCY_ONE_EDGE", "FIT_SPLINE_CANNOT_EVALUATE_END_CONDITION", "FIT_SPLINE_REPEATED_POINT", "FEATURE_ID_REQUIRED", "PARAMETER_NOT_FOUND", "PARAMETER_DOES_NOT_MATCH_ITS_FEATURE_SPEC", "SHEET_METAL_CORNER_BREAK_DISABLED", "SHEET_METAL_FILLET_NO_CONIC", "SHEET_METAL_CHAMFER_NO_TWO_OFFSETS", "SHEET_METAL_CHAMFER_NO_OFFSET_ANGLE", "SHEET_METAL_CHAMFER_MUST_BE_EQUAL_OFFSETS", "SHEET_METAL_ACTIVE_ENTITY_NEEDED", "SHEET_METAL_CORNER_BREAK_NOT_A_CORNER", "SHEET_METAL_CORNER_BREAK_NO_WALL", "SHEET_METAL_CORNER_BREAK_VERTEX_NOT_FREE", "SHEET_METAL_CORNER_BREAK_ATTRIBUTE_EXISTS", "FIT_SPLINE_ZERO_START_MAGNITUDE", "FIT_SPLINE_ZERO_END_MAGNITUDE", "SHEET_METAL_CORNER_BREAK_SELECT_ENTITIES", "EXTRUDE_SELECT_TERMINATING_VERTEX", "FILL_SURFACE_NO_EDGES", "FILL_SURFACE_DOUBLE_SELECTION", "FILL_SURFACE_MULTI_LOOP", "FILL_SURFACE_OPEN_LOOP", "FILL_SURFACE_FAIL", "FILL_SURFACE_ATTACH_FAIL", "FILL_SURFACE_G2_FAIL", "FILL_SURFACE_VERTEX_INTERPOLATION_FAIL", "LOFT_SPINE_DISJOINT_PATH", "LOFT_SPINE_SELF_INTERSECTING_PATH", "LOFT_SPINE_PATH_PROFILE_NO_INTERSECTION", "LOFT_SPINE_FAILED_XSECTIONS", "LOFT_SPINE_GUIDE_WITH_POINT_PROFILE", "LOFT_SPINE_PROFILES_NOT_IN_ORDER", "LOFT_SELECT_SPINE", "DOCUMENT_NOT_FOUND", "ELEMENT_NOT_FOUND", "ENCLOSE_NO_REGION", "ENCLOSE_CANNOT_MERGE_REGIONS", "ENCLOSE_CANNOT_CREATE_SOLID", "ENCLOSE_NOTHING_SELECTED", "ENCLOSE_UNKNOWN_ERROR", "ACCESS_NOT_ALLOWED", "LOFT_SPINE_TOO_MANY_GUIDES", "FEATURE_INVALID_NAMESPACE", "FEATURE_NULL_NOT_ALLOWED", "SKETCH_DIMENSION_LIMIT_ERROR", "FILL_SURFACE_WIRE_CONTINUITY_MISMATCH", "FILL_SURFACE_INTERNAL_CONTINUITY_MISMATCH", "LOFT_START_OR_END_CONDITIONS_FAILED", "LOFT_START_OR_END_CONDITIONS_MAGNITUDE_NO_EFFECT", "FOLLOW_LEADER_IS_IN_UNFOLLOWABLE_TAB", "LOFT_START_OR_END_CONDITIONS_WITH_GUIDES_FAILED", "REST_ASSEMBLY_MISSING_TRANSFORM_GROUPS", "REST_ASSEMBLY_NULL_TRANSFORM_GROUP", "REST_ASSEMBLY_NULL_TRANSFORM_GROUP_INSTANCES", "REST_ASSEMBLY_NULL_TRANSFORM_GROUP_INSTANCE", "LOFT_NO_FACE_FOR_GUIDE_CLAMP", "LOFT_NO_CONTINUITY_CONDITION_AT_INTERNAL_GUIDE", "SKETCH_CONSTRAINT_NOT_FOUND", "SKETCH_CONSTRAINT_PARAMETER_NOT_FOUND", "SKETCH_ENTITY_NOT_FOUND", "SKETCH_ENTITY_PARAMETER_NOT_FOUND", "FEATURE_PARAMETER_TYPE_MISMATCH", "FEATURE_CONFIGURED_PARAMETER_NO_VALUES", "FEATURE_CONFIGURED_PARAMETER_INCONSISTENT_TYPES", "SHEET_METAL_FLANGE_FAIL_AUTO_MITER", "SHEET_METAL_FLANGE_FAIL_PARALLEL_EDGE", "SHEET_METAL_FLANGE_FAIL_PARALLEL_PLANE", "SHEET_METAL_FLANGE_FAIL_PARALLEL_DIRECTION", "SHEET_METAL_FLANGE_FAIL_NO_BEND", "SHEET_METAL_FLANGE_NO_PARALLEL_ENTITY", "SHEET_METAL_FLANGE_NO_DIRECTION_ENTITY", "SHEET_METAL_TAB_NO_BEND", "BOOLEAN_NO_SURFACE_IN_MERGE_SCOPE", "BOOLEAN_NO_SHARED_EDGE_WITH_SURFACE_IN_MERGE_SCOPE", "SHEET_METAL_BEND_RELIEF_NO_CORNER", "SHEET_METAL_CORNER_SELECT_ENTITIES", "SHEET_METAL_BEND_RELIEF_SELECT_ENTITIES", "VRFILLET_RADIUS_REQUIRED_AT_VERTEX", "VRFILLET_RHO_REQUIRED_AT_VERTEX", "VRFILLET_MAG_REQUIRED_AT_VERTEX", "VRFILLET_SELECT_VERTICES", "VRFILLET_VERTEX_NOT_ON_CHAIN", "VRFILLET_INVALID_CHAIN", "SHEET_METAL_TAB_NO_MERGE", "SHEET_METAL_TAB_NONPLANAR", "SHEET_METAL_TAB_NO_WALL", "SHEET_METAL_TAB_NO_TAB", "VRFILLET_NO_EFFECT", "VRFILLET_MULTI_SELECTION", "SHEET_METAL_TAB_NO_PARALLEL_WALL", "SHEET_METAL_CORNER_UNDER_SIZED", "FILLET_PARTIAL_FAIL", "VRFILLET_INTERNAL_ZERO", "SHEET_METAL_TAB_NO_EFFECT", "SHEET_METAL_TAB_LOW_CLEARANCE", "SHEET_METAL_TAB_FAILS_MERGE", "SHEET_METAL_TAB_COLLISION", "REPLACE_FACE_FACE_COUNT_CHANGED", "FACE_OVERLAP", "FACE_REMOVED", "INTERSECTING_EDGES", "CANNOT_SPLIT_FACE", "FILL_SURFACE_BAD_SUPPORT", "FILL_SURFACE_SUPPORT_NOT_ON_BOUNDARY", "FILL_SURFACE_SUPPORT_NOT_SMOOTH", "FILL_CURVE_OR_POINT_CONSTRAINTS", "SHEET_METAL_ADD_WRONG_MODEL", "SHEET_METAL_PATTERN_DISABLED_BOOLEANS", "DRAWING_ALL_INSTANCES_HIDDEN", "FILL_SUPPORT_NOT_SMOOTH_INTERNAL", "SKETCH_CONSTRAINT_WRONG_SHEET_METAL_BODY", "SKETCH_CONSTRAINT_FLAT_IN_3D", "SKETCH_CONSTRAINT_3D_IN_FLAT", "FIT_SPLINE_CURVATURE_FACE", "FIT_SPLINE_CANNOT_EVALUATE_CURVATURE_END_CONDITION", "FIT_SPLINE_NEED_DIRECTION_FOR_CURVATURE", "CONFIGURATION_HAS_BAD_PARAMETERS", "CONFIGURATION_HAS_BAD_CURRENT_CONFIGURATION", "FEATURE_CONFIGURED_PARAMETER_VALUES_HAVE_IDS", "WORKSPACE_NO_LONGER_EXISTS", "CONTENT_STACKING_INVALID_MODE", "CONTENT_STACKING_INVALID_COMPONENTS", "CONTENT_STACKING_INVALID_TOP_STACK", "SHEET_METAL_FACE_PATTERN_NO_JOINT", "SHEET_METAL_FACE_PATTERN_FLOATING_CUT", "SHEET_METAL_FACE_PATTERN_FLOATING_WALL", "SM_FLAT_OP_NO_INTERSECT", "SM_FLAT_OP_PARTIAL_INTERSECT", "SM_FLAT_OP_ADD_CROSSES_EDGE", "SM_FLAT_OP_NON_PLANAR_TOOL", "SM_FLAT_OP_NON_PLANAR_TARGET", "SM_FLAT_OPERATION_FAILED", "SM_FLAT_OP_LEGACY_MODEL", "SHEET_METAL_FLANGE_NON_LINEAR_EDGES", "SHEET_METAL_CYLINDER_BEND", "SHEET_METAL_INVALID_FACE", "SHEET_METAL_ROLLED_CORNER_RELIF", "SHEET_METAL_RELIEF_FAILURES", "EDGE_CHANGE_FAILED", "BOOLEAN_INPUTS_NOT_SOLID", "TRANSFORM_SCALE_SELECTION", "SHEET_METAL_SUBTRACT_DESTROYS_SHEET", "SPLIT_KEEP_TOOLS_WITH_FACE", "SPLIT_TRIM_WITH_SINGLE_FACE", "SHEET_METAL_SKETCH_DETACHED_FACE", "HOLE_CUT_FAIL", "SHEET_METAL_FLAT_OP_ROLL_FAIL", "PATTERN_EDGE_FAILED", "SHEET_METAL_FACE_PATTERN_NO_VERTEX", "SHEET_METAL_FACE_PATTERN_PARTIAL_FLOATING_WALL", "EXTRUDE_3D_AND_FLAT", "PATTERN_SWITCH_TO_PER_INSTANCE", "PATTERN_NO_GEOM_FROM_FEATURES", "RM_NO_LINK_PERMISSION_TO_REVISION", "DRAFT_SELECT_PARTING_EDGES", "DRAFT_CONFLICTING_OPPOSITION", "SPLIT_SELECT_TARGETS", "SPLIT_SELECT_TOOL", "SPLIT_SELECT_FACE_TARGETS", "SPLIT_SELECT_FACE_TOOLS", "ASSEMBLY_PATTERN_EXCEED_MAX_INSTANCE_COUNT", "ASSEMBLY_PATTERN_RECURSIVE_SEED", "NO_LINK_PERMISSION_TO_THIS_DOCUMENT", "SM_FLAT_OP_FACES_NOT_COPLANAR", "FLATTENED_SHEET_METAL_SKETCH_PROHIBTED", "DRAFT_SELECT_PULL_DIRECTION_ENTITY", "DRAFT_PARALLEL_PARTING_EDGE", "FLATTENED_SHEET_METAL_SKETCH_ONE_FACE", "SKETCH_OFFSET_CHAIN_FAIL", "SKETCH_OFFSET_BASE_CURVE_CONSUMED", "SKETCH_OFFSET_SPLINE_SPLIT", "SKETCH_OFFSET_ELLIPSE_SPLIT", "CANNOT_FIND_FLATTENED_BODY", "SHEET_METAL_ACTIVE_MODEL_REQUIRED", "SKETCH_REFERENCE_WRONG_FLAT_PART", "SKETCH_CANNOT_REFERENCE_3D", "SM_FLAT_OP_CANNOT_JOIN_DIFFERENT_TRANSFORMS", "DEFINED_IN_3D_CANT_REFERENCE_SM_FLAT", "DEFINED_IN_SM_FLAT_CANT_REFERENCE_3D", "CANNOT_CHANGE_REFERENCE_TO_DELETED_DOCUMENT", "COPIED_SKETCH_NOT_FOUND", "VARIABLE_NAME_TOO_LONG", "NO_INSTANCE_TO_REPLACE", "ASSEMBLY_REPLACE_NO_REPLACER", "CANNOT_REPLACE_IN_SUBASSEMBLIES", "FILL_SURFACE_G1_FAIL", "ALL_CONFIGURATION_PARAMETERS_NOT_SPECIFIED", "ASSEMBLY_REPLACE_INVALID_SEED_INSTANCE", "ASSEMBLY_REPLACE_INVALID_SEED_TYPE", "ASSEMBLY_REPLACE_SUPPRESSED_FORBIDDEN", "DISPLAY_STATES_INVALID_NAME", "DISPLAY_STATES_DUPLICATE_NAME", "WORKSPACE_UPGRADE_NONE_ENABLE_CAPABILITY", "DISPLAY_STATES_UPDATE_HAD_NO_EFFECT", "DISPLAY_STATES_APPLY_HAD_NO_EFFECT", "DISPLAY_STATES_DOES_NOT_EXIST", "LOFT_SPINE_NONTANGENT_PATH", "LOFT_SPINE_APPROXIMATED", "REST_ASSEMBLY_REVISION_PART_NUMBER_BLANK", "REST_ASSEMBLY_REVISION_NOT_FOUND", "ROLL_FAILED", "ROLL_CANNOT_ADJUST", "ROLL_MISMATCHED_SOURCE", "INVALID_ROLL_SURFACE", "ROLL_NOT_TO_OR_FROM_PLANE", "FAILED_TO_FIND_ELEMENT_FOR_TO_STATE", "FAILED_TO_FIND_VERSION_FOR_TO_STATE", "MISSING_REVISION_ID_FOR_TO_STATE", "MISSING_VERSION_ID_FOR_TO_STATE", "INVALID_DOCUMENT_ID_FOR_TO_STATE", "ASSEMBLY_CONTAINS_MISSING_PART_DATA", "SHEET_METAL_HEM_NO_EDGES", "SHEET_METAL_HEM_NON_LINEAR_EDGES", "SHEET_METAL_HEM_FAIL_ALIGNMENT", "SHEET_METAL_HEM_TOO_SHORT", "SHEET_METAL_HEM_TEAR_DROP_GAP_TOO_LARGE", "SHEET_METAL_HEM_INTERNAL", "SHEET_METAL_HEM_FAILED", "INVALID_CONFIGURATION_SPECIFIED", "EDGEBLEND_PARTIAL", "CHAMFER_PARTIAL_FAIL", "LOFT_INCONSISTENT_EXTENT", "LOFT_CANT_TRIM_PROFILES_INFO", "LOFT_CANT_TRIM_GUIDES_INFO", "NON_GEOMETRIC_ITEM_INSERTION_FAILED", "UNKNOWN"]  # noqa: E501
        if error_enum not in allowed_values:
            raise ValueError(
                "Invalid value for `error_enum` ({0}), must be one of {1}"  # noqa: E501
                .format(error_enum, allowed_values)
            )

        self._error_enum = error_enum

    @property
    def bodies(self):
        """Gets the bodies of this BTExportTessellatedEdgesResponse.  # noqa: E501


        :return: The bodies of this BTExportTessellatedEdgesResponse.  # noqa: E501
        :rtype: list[BTExportTessellatedEdgesBody]
        """
        return self._bodies

    @bodies.setter
    def bodies(self, bodies):
        """Sets the bodies of this BTExportTessellatedEdgesResponse.


        :param bodies: The bodies of this BTExportTessellatedEdgesResponse.  # noqa: E501
        :type: list[BTExportTessellatedEdgesBody]
        """

        self._bodies = bodies

    @property
    def type_id(self):
        """Gets the type_id of this BTExportTessellatedEdgesResponse.  # noqa: E501


        :return: The type_id of this BTExportTessellatedEdgesResponse.  # noqa: E501
        :rtype: int
        """
        return self._type_id

    @type_id.setter
    def type_id(self, type_id):
        """Sets the type_id of this BTExportTessellatedEdgesResponse.


        :param type_id: The type_id of this BTExportTessellatedEdgesResponse.  # noqa: E501
        :type: int
        """

        self._type_id = type_id

    @property
    def connection_source(self):
        """Gets the connection_source of this BTExportTessellatedEdgesResponse.  # noqa: E501


        :return: The connection_source of this BTExportTessellatedEdgesResponse.  # noqa: E501
        :rtype: BTConnection
        """
        return self._connection_source

    @connection_source.setter
    def connection_source(self, connection_source):
        """Sets the connection_source of this BTExportTessellatedEdgesResponse.


        :param connection_source: The connection_source of this BTExportTessellatedEdgesResponse.  # noqa: E501
        :type: BTConnection
        """

        self._connection_source = connection_source

    @property
    def export_type_name(self):
        """Gets the export_type_name of this BTExportTessellatedEdgesResponse.  # noqa: E501


        :return: The export_type_name of this BTExportTessellatedEdgesResponse.  # noqa: E501
        :rtype: str
        """
        return self._export_type_name

    @export_type_name.setter
    def export_type_name(self, export_type_name):
        """Sets the export_type_name of this BTExportTessellatedEdgesResponse.


        :param export_type_name: The export_type_name of this BTExportTessellatedEdgesResponse.  # noqa: E501
        :type: str
        """

        self._export_type_name = export_type_name

    @property
    def unknown_class(self):
        """Gets the unknown_class of this BTExportTessellatedEdgesResponse.  # noqa: E501


        :return: The unknown_class of this BTExportTessellatedEdgesResponse.  # noqa: E501
        :rtype: bool
        """
        return self._unknown_class

    @unknown_class.setter
    def unknown_class(self, unknown_class):
        """Sets the unknown_class of this BTExportTessellatedEdgesResponse.


        :param unknown_class: The unknown_class of this BTExportTessellatedEdgesResponse.  # noqa: E501
        :type: bool
        """

        self._unknown_class = unknown_class

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTExportTessellatedEdgesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTMetricParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'system_id': 'str',
        'property_map': 'dict(str, object)',
        'event_name': 'str',
        'event_namespace': 'str',
        'event_time': 'datetime',
        'element_id': 'str',
        'event_type': 'int',
        'document_id': 'str'
    }

    attribute_map = {
        'system_id': 'systemId',
        'property_map': 'propertyMap',
        'event_name': 'eventName',
        'event_namespace': 'eventNamespace',
        'event_time': 'eventTime',
        'element_id': 'elementId',
        'event_type': 'eventType',
        'document_id': 'documentId'
    }

    def __init__(self, system_id=None, property_map=None, event_name=None, event_namespace=None, event_time=None, element_id=None, event_type=None, document_id=None):  # noqa: E501
        """BTMetricParams - a model defined in OpenAPI"""  # noqa: E501

        self._system_id = None
        self._property_map = None
        self._event_name = None
        self._event_namespace = None
        self._event_time = None
        self._element_id = None
        self._event_type = None
        self._document_id = None
        self.discriminator = None

        if system_id is not None:
            self.system_id = system_id
        if property_map is not None:
            self.property_map = property_map
        if event_name is not None:
            self.event_name = event_name
        if event_namespace is not None:
            self.event_namespace = event_namespace
        if event_time is not None:
            self.event_time = event_time
        if element_id is not None:
            self.element_id = element_id
        if event_type is not None:
            self.event_type = event_type
        if document_id is not None:
            self.document_id = document_id

    @property
    def system_id(self):
        """Gets the system_id of this BTMetricParams.  # noqa: E501


        :return: The system_id of this BTMetricParams.  # noqa: E501
        :rtype: str
        """
        return self._system_id

    @system_id.setter
    def system_id(self, system_id):
        """Sets the system_id of this BTMetricParams.


        :param system_id: The system_id of this BTMetricParams.  # noqa: E501
        :type: str
        """

        self._system_id = system_id

    @property
    def property_map(self):
        """Gets the property_map of this BTMetricParams.  # noqa: E501


        :return: The property_map of this BTMetricParams.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._property_map

    @property_map.setter
    def property_map(self, property_map):
        """Sets the property_map of this BTMetricParams.


        :param property_map: The property_map of this BTMetricParams.  # noqa: E501
        :type: dict(str, object)
        """

        self._property_map = property_map

    @property
    def event_name(self):
        """Gets the event_name of this BTMetricParams.  # noqa: E501


        :return: The event_name of this BTMetricParams.  # noqa: E501
        :rtype: str
        """
        return self._event_name

    @event_name.setter
    def event_name(self, event_name):
        """Sets the event_name of this BTMetricParams.


        :param event_name: The event_name of this BTMetricParams.  # noqa: E501
        :type: str
        """

        self._event_name = event_name

    @property
    def event_namespace(self):
        """Gets the event_namespace of this BTMetricParams.  # noqa: E501


        :return: The event_namespace of this BTMetricParams.  # noqa: E501
        :rtype: str
        """
        return self._event_namespace

    @event_namespace.setter
    def event_namespace(self, event_namespace):
        """Sets the event_namespace of this BTMetricParams.


        :param event_namespace: The event_namespace of this BTMetricParams.  # noqa: E501
        :type: str
        """

        self._event_namespace = event_namespace

    @property
    def event_time(self):
        """Gets the event_time of this BTMetricParams.  # noqa: E501


        :return: The event_time of this BTMetricParams.  # noqa: E501
        :rtype: datetime
        """
        return self._event_time

    @event_time.setter
    def event_time(self, event_time):
        """Sets the event_time of this BTMetricParams.


        :param event_time: The event_time of this BTMetricParams.  # noqa: E501
        :type: datetime
        """

        self._event_time = event_time

    @property
    def element_id(self):
        """Gets the element_id of this BTMetricParams.  # noqa: E501


        :return: The element_id of this BTMetricParams.  # noqa: E501
        :rtype: str
        """
        return self._element_id

    @element_id.setter
    def element_id(self, element_id):
        """Sets the element_id of this BTMetricParams.


        :param element_id: The element_id of this BTMetricParams.  # noqa: E501
        :type: str
        """

        self._element_id = element_id

    @property
    def event_type(self):
        """Gets the event_type of this BTMetricParams.  # noqa: E501


        :return: The event_type of this BTMetricParams.  # noqa: E501
        :rtype: int
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        """Sets the event_type of this BTMetricParams.


        :param event_type: The event_type of this BTMetricParams.  # noqa: E501
        :type: int
        """

        self._event_type = event_type

    @property
    def document_id(self):
        """Gets the document_id of this BTMetricParams.  # noqa: E501


        :return: The document_id of this BTMetricParams.  # noqa: E501
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """Sets the document_id of this BTMetricParams.


        :param document_id: The document_id of this BTMetricParams.  # noqa: E501
        :type: str
        """

        self._document_id = document_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTMetricParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTWorkspaceInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'is_read_only': 'bool',
        'can_delete': 'bool',
        'parent': 'str',
        'type': 'str',
        'description': 'str',
        'microversion': 'str',
        'created_at': 'datetime',
        'modified_at': 'datetime',
        'last_modifier': 'BTUserBasicSummaryInfo',
        'document_id': 'str',
        'thumbnail': 'BTThumbnailInfo',
        'parents': 'list[BTVersionInfo]',
        'creator': 'BTUserBasicSummaryInfo',
        'override_date': 'datetime',
        'name': 'str',
        'id': 'str',
        'href': 'str',
        'view_ref': 'str'
    }

    attribute_map = {
        'is_read_only': 'isReadOnly',
        'can_delete': 'canDelete',
        'parent': 'parent',
        'type': 'type',
        'description': 'description',
        'microversion': 'microversion',
        'created_at': 'createdAt',
        'modified_at': 'modifiedAt',
        'last_modifier': 'lastModifier',
        'document_id': 'documentId',
        'thumbnail': 'thumbnail',
        'parents': 'parents',
        'creator': 'creator',
        'override_date': 'overrideDate',
        'name': 'name',
        'id': 'id',
        'href': 'href',
        'view_ref': 'viewRef'
    }

    def __init__(self, is_read_only=None, can_delete=None, parent=None, type=None, description=None, microversion=None, created_at=None, modified_at=None, last_modifier=None, document_id=None, thumbnail=None, parents=None, creator=None, override_date=None, name=None, id=None, href=None, view_ref=None):  # noqa: E501
        """BTWorkspaceInfo - a model defined in OpenAPI"""  # noqa: E501

        self._is_read_only = None
        self._can_delete = None
        self._parent = None
        self._type = None
        self._description = None
        self._microversion = None
        self._created_at = None
        self._modified_at = None
        self._last_modifier = None
        self._document_id = None
        self._thumbnail = None
        self._parents = None
        self._creator = None
        self._override_date = None
        self._name = None
        self._id = None
        self._href = None
        self._view_ref = None
        self.discriminator = None

        if is_read_only is not None:
            self.is_read_only = is_read_only
        if can_delete is not None:
            self.can_delete = can_delete
        if parent is not None:
            self.parent = parent
        if type is not None:
            self.type = type
        if description is not None:
            self.description = description
        if microversion is not None:
            self.microversion = microversion
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at
        if last_modifier is not None:
            self.last_modifier = last_modifier
        if document_id is not None:
            self.document_id = document_id
        if thumbnail is not None:
            self.thumbnail = thumbnail
        if parents is not None:
            self.parents = parents
        if creator is not None:
            self.creator = creator
        if override_date is not None:
            self.override_date = override_date
        if name is not None:
            self.name = name
        if id is not None:
            self.id = id
        if href is not None:
            self.href = href
        if view_ref is not None:
            self.view_ref = view_ref

    @property
    def is_read_only(self):
        """Gets the is_read_only of this BTWorkspaceInfo.  # noqa: E501


        :return: The is_read_only of this BTWorkspaceInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_read_only

    @is_read_only.setter
    def is_read_only(self, is_read_only):
        """Sets the is_read_only of this BTWorkspaceInfo.


        :param is_read_only: The is_read_only of this BTWorkspaceInfo.  # noqa: E501
        :type: bool
        """

        self._is_read_only = is_read_only

    @property
    def can_delete(self):
        """Gets the can_delete of this BTWorkspaceInfo.  # noqa: E501


        :return: The can_delete of this BTWorkspaceInfo.  # noqa: E501
        :rtype: bool
        """
        return self._can_delete

    @can_delete.setter
    def can_delete(self, can_delete):
        """Sets the can_delete of this BTWorkspaceInfo.


        :param can_delete: The can_delete of this BTWorkspaceInfo.  # noqa: E501
        :type: bool
        """

        self._can_delete = can_delete

    @property
    def parent(self):
        """Gets the parent of this BTWorkspaceInfo.  # noqa: E501


        :return: The parent of this BTWorkspaceInfo.  # noqa: E501
        :rtype: str
        """
        return self._parent

    @parent.setter
    def parent(self, parent):
        """Sets the parent of this BTWorkspaceInfo.


        :param parent: The parent of this BTWorkspaceInfo.  # noqa: E501
        :type: str
        """

        self._parent = parent

    @property
    def type(self):
        """Gets the type of this BTWorkspaceInfo.  # noqa: E501


        :return: The type of this BTWorkspaceInfo.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this BTWorkspaceInfo.


        :param type: The type of this BTWorkspaceInfo.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def description(self):
        """Gets the description of this BTWorkspaceInfo.  # noqa: E501


        :return: The description of this BTWorkspaceInfo.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BTWorkspaceInfo.


        :param description: The description of this BTWorkspaceInfo.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def microversion(self):
        """Gets the microversion of this BTWorkspaceInfo.  # noqa: E501


        :return: The microversion of this BTWorkspaceInfo.  # noqa: E501
        :rtype: str
        """
        return self._microversion

    @microversion.setter
    def microversion(self, microversion):
        """Sets the microversion of this BTWorkspaceInfo.


        :param microversion: The microversion of this BTWorkspaceInfo.  # noqa: E501
        :type: str
        """

        self._microversion = microversion

    @property
    def created_at(self):
        """Gets the created_at of this BTWorkspaceInfo.  # noqa: E501


        :return: The created_at of this BTWorkspaceInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this BTWorkspaceInfo.


        :param created_at: The created_at of this BTWorkspaceInfo.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this BTWorkspaceInfo.  # noqa: E501


        :return: The modified_at of this BTWorkspaceInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this BTWorkspaceInfo.


        :param modified_at: The modified_at of this BTWorkspaceInfo.  # noqa: E501
        :type: datetime
        """

        self._modified_at = modified_at

    @property
    def last_modifier(self):
        """Gets the last_modifier of this BTWorkspaceInfo.  # noqa: E501


        :return: The last_modifier of this BTWorkspaceInfo.  # noqa: E501
        :rtype: BTUserBasicSummaryInfo
        """
        return self._last_modifier

    @last_modifier.setter
    def last_modifier(self, last_modifier):
        """Sets the last_modifier of this BTWorkspaceInfo.


        :param last_modifier: The last_modifier of this BTWorkspaceInfo.  # noqa: E501
        :type: BTUserBasicSummaryInfo
        """

        self._last_modifier = last_modifier

    @property
    def document_id(self):
        """Gets the document_id of this BTWorkspaceInfo.  # noqa: E501


        :return: The document_id of this BTWorkspaceInfo.  # noqa: E501
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """Sets the document_id of this BTWorkspaceInfo.


        :param document_id: The document_id of this BTWorkspaceInfo.  # noqa: E501
        :type: str
        """

        self._document_id = document_id

    @property
    def thumbnail(self):
        """Gets the thumbnail of this BTWorkspaceInfo.  # noqa: E501


        :return: The thumbnail of this BTWorkspaceInfo.  # noqa: E501
        :rtype: BTThumbnailInfo
        """
        return self._thumbnail

    @thumbnail.setter
    def thumbnail(self, thumbnail):
        """Sets the thumbnail of this BTWorkspaceInfo.


        :param thumbnail: The thumbnail of this BTWorkspaceInfo.  # noqa: E501
        :type: BTThumbnailInfo
        """

        self._thumbnail = thumbnail

    @property
    def parents(self):
        """Gets the parents of this BTWorkspaceInfo.  # noqa: E501


        :return: The parents of this BTWorkspaceInfo.  # noqa: E501
        :rtype: list[BTVersionInfo]
        """
        return self._parents

    @parents.setter
    def parents(self, parents):
        """Sets the parents of this BTWorkspaceInfo.


        :param parents: The parents of this BTWorkspaceInfo.  # noqa: E501
        :type: list[BTVersionInfo]
        """

        self._parents = parents

    @property
    def creator(self):
        """Gets the creator of this BTWorkspaceInfo.  # noqa: E501


        :return: The creator of this BTWorkspaceInfo.  # noqa: E501
        :rtype: BTUserBasicSummaryInfo
        """
        return self._creator

    @creator.setter
    def creator(self, creator):
        """Sets the creator of this BTWorkspaceInfo.


        :param creator: The creator of this BTWorkspaceInfo.  # noqa: E501
        :type: BTUserBasicSummaryInfo
        """

        self._creator = creator

    @property
    def override_date(self):
        """Gets the override_date of this BTWorkspaceInfo.  # noqa: E501


        :return: The override_date of this BTWorkspaceInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._override_date

    @override_date.setter
    def override_date(self, override_date):
        """Sets the override_date of this BTWorkspaceInfo.


        :param override_date: The override_date of this BTWorkspaceInfo.  # noqa: E501
        :type: datetime
        """

        self._override_date = override_date

    @property
    def name(self):
        """Gets the name of this BTWorkspaceInfo.  # noqa: E501


        :return: The name of this BTWorkspaceInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTWorkspaceInfo.


        :param name: The name of this BTWorkspaceInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this BTWorkspaceInfo.  # noqa: E501


        :return: The id of this BTWorkspaceInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BTWorkspaceInfo.


        :param id: The id of this BTWorkspaceInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def href(self):
        """Gets the href of this BTWorkspaceInfo.  # noqa: E501


        :return: The href of this BTWorkspaceInfo.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this BTWorkspaceInfo.


        :param href: The href of this BTWorkspaceInfo.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def view_ref(self):
        """Gets the view_ref of this BTWorkspaceInfo.  # noqa: E501


        :return: The view_ref of this BTWorkspaceInfo.  # noqa: E501
        :rtype: str
        """
        return self._view_ref

    @view_ref.setter
    def view_ref(self, view_ref):
        """Sets the view_ref of this BTWorkspaceInfo.


        :param view_ref: The view_ref of this BTWorkspaceInfo.  # noqa: E501
        :type: str
        """

        self._view_ref = view_ref

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTWorkspaceInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTWorkflowActionInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'tooltip': 'str',
        'allow_if_no_approvers': 'bool',
        'allow_if_approvers': 'bool',
        'always_allow': 'bool',
        'is_approver_action': 'bool',
        'label': 'str',
        'is_admin_override': 'bool',
        'action': 'str',
        'required_properties': 'list[str]',
        'ui_hint': 'str'
    }

    attribute_map = {
        'tooltip': 'tooltip',
        'allow_if_no_approvers': 'allowIfNoApprovers',
        'allow_if_approvers': 'allowIfApprovers',
        'always_allow': 'alwaysAllow',
        'is_approver_action': 'isApproverAction',
        'label': 'label',
        'is_admin_override': 'isAdminOverride',
        'action': 'action',
        'required_properties': 'requiredProperties',
        'ui_hint': 'uiHint'
    }

    def __init__(self, tooltip=None, allow_if_no_approvers=None, allow_if_approvers=None, always_allow=None, is_approver_action=None, label=None, is_admin_override=None, action=None, required_properties=None, ui_hint=None):  # noqa: E501
        """BTWorkflowActionInfo - a model defined in OpenAPI"""  # noqa: E501

        self._tooltip = None
        self._allow_if_no_approvers = None
        self._allow_if_approvers = None
        self._always_allow = None
        self._is_approver_action = None
        self._label = None
        self._is_admin_override = None
        self._action = None
        self._required_properties = None
        self._ui_hint = None
        self.discriminator = None

        if tooltip is not None:
            self.tooltip = tooltip
        if allow_if_no_approvers is not None:
            self.allow_if_no_approvers = allow_if_no_approvers
        if allow_if_approvers is not None:
            self.allow_if_approvers = allow_if_approvers
        if always_allow is not None:
            self.always_allow = always_allow
        if is_approver_action is not None:
            self.is_approver_action = is_approver_action
        if label is not None:
            self.label = label
        if is_admin_override is not None:
            self.is_admin_override = is_admin_override
        if action is not None:
            self.action = action
        if required_properties is not None:
            self.required_properties = required_properties
        if ui_hint is not None:
            self.ui_hint = ui_hint

    @property
    def tooltip(self):
        """Gets the tooltip of this BTWorkflowActionInfo.  # noqa: E501


        :return: The tooltip of this BTWorkflowActionInfo.  # noqa: E501
        :rtype: str
        """
        return self._tooltip

    @tooltip.setter
    def tooltip(self, tooltip):
        """Sets the tooltip of this BTWorkflowActionInfo.


        :param tooltip: The tooltip of this BTWorkflowActionInfo.  # noqa: E501
        :type: str
        """

        self._tooltip = tooltip

    @property
    def allow_if_no_approvers(self):
        """Gets the allow_if_no_approvers of this BTWorkflowActionInfo.  # noqa: E501


        :return: The allow_if_no_approvers of this BTWorkflowActionInfo.  # noqa: E501
        :rtype: bool
        """
        return self._allow_if_no_approvers

    @allow_if_no_approvers.setter
    def allow_if_no_approvers(self, allow_if_no_approvers):
        """Sets the allow_if_no_approvers of this BTWorkflowActionInfo.


        :param allow_if_no_approvers: The allow_if_no_approvers of this BTWorkflowActionInfo.  # noqa: E501
        :type: bool
        """

        self._allow_if_no_approvers = allow_if_no_approvers

    @property
    def allow_if_approvers(self):
        """Gets the allow_if_approvers of this BTWorkflowActionInfo.  # noqa: E501


        :return: The allow_if_approvers of this BTWorkflowActionInfo.  # noqa: E501
        :rtype: bool
        """
        return self._allow_if_approvers

    @allow_if_approvers.setter
    def allow_if_approvers(self, allow_if_approvers):
        """Sets the allow_if_approvers of this BTWorkflowActionInfo.


        :param allow_if_approvers: The allow_if_approvers of this BTWorkflowActionInfo.  # noqa: E501
        :type: bool
        """

        self._allow_if_approvers = allow_if_approvers

    @property
    def always_allow(self):
        """Gets the always_allow of this BTWorkflowActionInfo.  # noqa: E501


        :return: The always_allow of this BTWorkflowActionInfo.  # noqa: E501
        :rtype: bool
        """
        return self._always_allow

    @always_allow.setter
    def always_allow(self, always_allow):
        """Sets the always_allow of this BTWorkflowActionInfo.


        :param always_allow: The always_allow of this BTWorkflowActionInfo.  # noqa: E501
        :type: bool
        """

        self._always_allow = always_allow

    @property
    def is_approver_action(self):
        """Gets the is_approver_action of this BTWorkflowActionInfo.  # noqa: E501


        :return: The is_approver_action of this BTWorkflowActionInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_approver_action

    @is_approver_action.setter
    def is_approver_action(self, is_approver_action):
        """Sets the is_approver_action of this BTWorkflowActionInfo.


        :param is_approver_action: The is_approver_action of this BTWorkflowActionInfo.  # noqa: E501
        :type: bool
        """

        self._is_approver_action = is_approver_action

    @property
    def label(self):
        """Gets the label of this BTWorkflowActionInfo.  # noqa: E501


        :return: The label of this BTWorkflowActionInfo.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this BTWorkflowActionInfo.


        :param label: The label of this BTWorkflowActionInfo.  # noqa: E501
        :type: str
        """

        self._label = label

    @property
    def is_admin_override(self):
        """Gets the is_admin_override of this BTWorkflowActionInfo.  # noqa: E501


        :return: The is_admin_override of this BTWorkflowActionInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_admin_override

    @is_admin_override.setter
    def is_admin_override(self, is_admin_override):
        """Sets the is_admin_override of this BTWorkflowActionInfo.


        :param is_admin_override: The is_admin_override of this BTWorkflowActionInfo.  # noqa: E501
        :type: bool
        """

        self._is_admin_override = is_admin_override

    @property
    def action(self):
        """Gets the action of this BTWorkflowActionInfo.  # noqa: E501


        :return: The action of this BTWorkflowActionInfo.  # noqa: E501
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this BTWorkflowActionInfo.


        :param action: The action of this BTWorkflowActionInfo.  # noqa: E501
        :type: str
        """

        self._action = action

    @property
    def required_properties(self):
        """Gets the required_properties of this BTWorkflowActionInfo.  # noqa: E501


        :return: The required_properties of this BTWorkflowActionInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._required_properties

    @required_properties.setter
    def required_properties(self, required_properties):
        """Sets the required_properties of this BTWorkflowActionInfo.


        :param required_properties: The required_properties of this BTWorkflowActionInfo.  # noqa: E501
        :type: list[str]
        """

        self._required_properties = required_properties

    @property
    def ui_hint(self):
        """Gets the ui_hint of this BTWorkflowActionInfo.  # noqa: E501


        :return: The ui_hint of this BTWorkflowActionInfo.  # noqa: E501
        :rtype: str
        """
        return self._ui_hint

    @ui_hint.setter
    def ui_hint(self, ui_hint):
        """Sets the ui_hint of this BTWorkflowActionInfo.


        :param ui_hint: The ui_hint of this BTWorkflowActionInfo.  # noqa: E501
        :type: str
        """

        self._ui_hint = ui_hint

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTWorkflowActionInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTMoveElementInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'new_document_version_id': 'str',
        'error_message': 'str',
        'new_document_id': 'str',
        'element_original_to_new_map': 'dict(str, str)',
        'is_new_document': 'bool',
        'new_document_name': 'str',
        'new_workspace_id': 'str'
    }

    attribute_map = {
        'new_document_version_id': 'newDocumentVersionId',
        'error_message': 'errorMessage',
        'new_document_id': 'newDocumentId',
        'element_original_to_new_map': 'elementOriginalToNewMap',
        'is_new_document': 'isNewDocument',
        'new_document_name': 'newDocumentName',
        'new_workspace_id': 'newWorkspaceId'
    }

    def __init__(self, new_document_version_id=None, error_message=None, new_document_id=None, element_original_to_new_map=None, is_new_document=None, new_document_name=None, new_workspace_id=None):  # noqa: E501
        """BTMoveElementInfo - a model defined in OpenAPI"""  # noqa: E501

        self._new_document_version_id = None
        self._error_message = None
        self._new_document_id = None
        self._element_original_to_new_map = None
        self._is_new_document = None
        self._new_document_name = None
        self._new_workspace_id = None
        self.discriminator = None

        if new_document_version_id is not None:
            self.new_document_version_id = new_document_version_id
        if error_message is not None:
            self.error_message = error_message
        if new_document_id is not None:
            self.new_document_id = new_document_id
        if element_original_to_new_map is not None:
            self.element_original_to_new_map = element_original_to_new_map
        if is_new_document is not None:
            self.is_new_document = is_new_document
        if new_document_name is not None:
            self.new_document_name = new_document_name
        if new_workspace_id is not None:
            self.new_workspace_id = new_workspace_id

    @property
    def new_document_version_id(self):
        """Gets the new_document_version_id of this BTMoveElementInfo.  # noqa: E501


        :return: The new_document_version_id of this BTMoveElementInfo.  # noqa: E501
        :rtype: str
        """
        return self._new_document_version_id

    @new_document_version_id.setter
    def new_document_version_id(self, new_document_version_id):
        """Sets the new_document_version_id of this BTMoveElementInfo.


        :param new_document_version_id: The new_document_version_id of this BTMoveElementInfo.  # noqa: E501
        :type: str
        """

        self._new_document_version_id = new_document_version_id

    @property
    def error_message(self):
        """Gets the error_message of this BTMoveElementInfo.  # noqa: E501


        :return: The error_message of this BTMoveElementInfo.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this BTMoveElementInfo.


        :param error_message: The error_message of this BTMoveElementInfo.  # noqa: E501
        :type: str
        """

        self._error_message = error_message

    @property
    def new_document_id(self):
        """Gets the new_document_id of this BTMoveElementInfo.  # noqa: E501


        :return: The new_document_id of this BTMoveElementInfo.  # noqa: E501
        :rtype: str
        """
        return self._new_document_id

    @new_document_id.setter
    def new_document_id(self, new_document_id):
        """Sets the new_document_id of this BTMoveElementInfo.


        :param new_document_id: The new_document_id of this BTMoveElementInfo.  # noqa: E501
        :type: str
        """

        self._new_document_id = new_document_id

    @property
    def element_original_to_new_map(self):
        """Gets the element_original_to_new_map of this BTMoveElementInfo.  # noqa: E501


        :return: The element_original_to_new_map of this BTMoveElementInfo.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._element_original_to_new_map

    @element_original_to_new_map.setter
    def element_original_to_new_map(self, element_original_to_new_map):
        """Sets the element_original_to_new_map of this BTMoveElementInfo.


        :param element_original_to_new_map: The element_original_to_new_map of this BTMoveElementInfo.  # noqa: E501
        :type: dict(str, str)
        """

        self._element_original_to_new_map = element_original_to_new_map

    @property
    def is_new_document(self):
        """Gets the is_new_document of this BTMoveElementInfo.  # noqa: E501


        :return: The is_new_document of this BTMoveElementInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_new_document

    @is_new_document.setter
    def is_new_document(self, is_new_document):
        """Sets the is_new_document of this BTMoveElementInfo.


        :param is_new_document: The is_new_document of this BTMoveElementInfo.  # noqa: E501
        :type: bool
        """

        self._is_new_document = is_new_document

    @property
    def new_document_name(self):
        """Gets the new_document_name of this BTMoveElementInfo.  # noqa: E501


        :return: The new_document_name of this BTMoveElementInfo.  # noqa: E501
        :rtype: str
        """
        return self._new_document_name

    @new_document_name.setter
    def new_document_name(self, new_document_name):
        """Sets the new_document_name of this BTMoveElementInfo.


        :param new_document_name: The new_document_name of this BTMoveElementInfo.  # noqa: E501
        :type: str
        """

        self._new_document_name = new_document_name

    @property
    def new_workspace_id(self):
        """Gets the new_workspace_id of this BTMoveElementInfo.  # noqa: E501


        :return: The new_workspace_id of this BTMoveElementInfo.  # noqa: E501
        :rtype: str
        """
        return self._new_workspace_id

    @new_workspace_id.setter
    def new_workspace_id(self, new_workspace_id):
        """Sets the new_workspace_id of this BTMoveElementInfo.


        :param new_workspace_id: The new_workspace_id of this BTMoveElementInfo.  # noqa: E501
        :type: str
        """

        self._new_workspace_id = new_workspace_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTMoveElementInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class Schema(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'title': 'str',
        'multiple_of': 'float',
        'maximum': 'float',
        'exclusive_maximum': 'bool',
        'minimum': 'float',
        'exclusive_minimum': 'bool',
        'max_length': 'int',
        'min_length': 'int',
        'pattern': 'str',
        'max_items': 'int',
        'min_items': 'int',
        'unique_items': 'bool',
        'max_properties': 'int',
        'min_properties': 'int',
        'required': 'list[str]',
        'type': 'str',
        '_not': 'Schema',
        'properties': 'dict(str, Schema)',
        'default': 'object',
        'description': 'str',
        'format': 'str',
        'getref': 'str',
        'nullable': 'bool',
        'read_only': 'bool',
        'write_only': 'bool',
        'external_docs': 'ExternalDocumentation',
        'deprecated': 'bool',
        'xml': 'XML',
        'extensions': 'dict(str, object)',
        'discriminator': 'Discriminator',
        'enum': 'list[object]'
    }

    attribute_map = {
        'title': 'title',
        'multiple_of': 'multipleOf',
        'maximum': 'maximum',
        'exclusive_maximum': 'exclusiveMaximum',
        'minimum': 'minimum',
        'exclusive_minimum': 'exclusiveMinimum',
        'max_length': 'maxLength',
        'min_length': 'minLength',
        'pattern': 'pattern',
        'max_items': 'maxItems',
        'min_items': 'minItems',
        'unique_items': 'uniqueItems',
        'max_properties': 'maxProperties',
        'min_properties': 'minProperties',
        'required': 'required',
        'type': 'type',
        '_not': 'not',
        'properties': 'properties',
        'default': 'default',
        'description': 'description',
        'format': 'format',
        'getref': 'get$ref',
        'nullable': 'nullable',
        'read_only': 'readOnly',
        'write_only': 'writeOnly',
        'external_docs': 'externalDocs',
        'deprecated': 'deprecated',
        'xml': 'xml',
        'extensions': 'extensions',
        'discriminator': 'discriminator',
        'enum': 'enum'
    }

    def __init__(self, title=None, multiple_of=None, maximum=None, exclusive_maximum=None, minimum=None, exclusive_minimum=None, max_length=None, min_length=None, pattern=None, max_items=None, min_items=None, unique_items=None, max_properties=None, min_properties=None, required=None, type=None, _not=None, properties=None, default=None, description=None, format=None, getref=None, nullable=None, read_only=None, write_only=None, external_docs=None, deprecated=None, xml=None, extensions=None, discriminator=None, enum=None):  # noqa: E501
        """Schema - a model defined in OpenAPI"""  # noqa: E501

        self._title = None
        self._multiple_of = None
        self._maximum = None
        self._exclusive_maximum = None
        self._minimum = None
        self._exclusive_minimum = None
        self._max_length = None
        self._min_length = None
        self._pattern = None
        self._max_items = None
        self._min_items = None
        self._unique_items = None
        self._max_properties = None
        self._min_properties = None
        self._required = None
        self._type = None
        self.__not = None
        self._properties = None
        self._default = None
        self._description = None
        self._format = None
        self._getref = None
        self._nullable = None
        self._read_only = None
        self._write_only = None
        self._external_docs = None
        self._deprecated = None
        self._xml = None
        self._extensions = None
        self._discriminator = None
        self._enum = None
        self.discriminator = None

        if title is not None:
            self.title = title
        if multiple_of is not None:
            self.multiple_of = multiple_of
        if maximum is not None:
            self.maximum = maximum
        if exclusive_maximum is not None:
            self.exclusive_maximum = exclusive_maximum
        if minimum is not None:
            self.minimum = minimum
        if exclusive_minimum is not None:
            self.exclusive_minimum = exclusive_minimum
        if max_length is not None:
            self.max_length = max_length
        if min_length is not None:
            self.min_length = min_length
        if pattern is not None:
            self.pattern = pattern
        if max_items is not None:
            self.max_items = max_items
        if min_items is not None:
            self.min_items = min_items
        if unique_items is not None:
            self.unique_items = unique_items
        if max_properties is not None:
            self.max_properties = max_properties
        if min_properties is not None:
            self.min_properties = min_properties
        if required is not None:
            self.required = required
        if type is not None:
            self.type = type
        if _not is not None:
            self._not = _not
        if properties is not None:
            self.properties = properties
        if default is not None:
            self.default = default
        if description is not None:
            self.description = description
        if format is not None:
            self.format = format
        if getref is not None:
            self.getref = getref
        if nullable is not None:
            self.nullable = nullable
        if read_only is not None:
            self.read_only = read_only
        if write_only is not None:
            self.write_only = write_only
        if external_docs is not None:
            self.external_docs = external_docs
        if deprecated is not None:
            self.deprecated = deprecated
        if xml is not None:
            self.xml = xml
        if extensions is not None:
            self.extensions = extensions
        if discriminator is not None:
            self.discriminator = discriminator
        if enum is not None:
            self.enum = enum

    @property
    def title(self):
        """Gets the title of this Schema.  # noqa: E501


        :return: The title of this Schema.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this Schema.


        :param title: The title of this Schema.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def multiple_of(self):
        """Gets the multiple_of of this Schema.  # noqa: E501


        :return: The multiple_of of this Schema.  # noqa: E501
        :rtype: float
        """
        return self._multiple_of

    @multiple_of.setter
    def multiple_of(self, multiple_of):
        """Sets the multiple_of of this Schema.


        :param multiple_of: The multiple_of of this Schema.  # noqa: E501
        :type: float
        """

        self._multiple_of = multiple_of

    @property
    def maximum(self):
        """Gets the maximum of this Schema.  # noqa: E501


        :return: The maximum of this Schema.  # noqa: E501
        :rtype: float
        """
        return self._maximum

    @maximum.setter
    def maximum(self, maximum):
        """Sets the maximum of this Schema.


        :param maximum: The maximum of this Schema.  # noqa: E501
        :type: float
        """

        self._maximum = maximum

    @property
    def exclusive_maximum(self):
        """Gets the exclusive_maximum of this Schema.  # noqa: E501


        :return: The exclusive_maximum of this Schema.  # noqa: E501
        :rtype: bool
        """
        return self._exclusive_maximum

    @exclusive_maximum.setter
    def exclusive_maximum(self, exclusive_maximum):
        """Sets the exclusive_maximum of this Schema.


        :param exclusive_maximum: The exclusive_maximum of this Schema.  # noqa: E501
        :type: bool
        """

        self._exclusive_maximum = exclusive_maximum

    @property
    def minimum(self):
        """Gets the minimum of this Schema.  # noqa: E501


        :return: The minimum of this Schema.  # noqa: E501
        :rtype: float
        """
        return self._minimum

    @minimum.setter
    def minimum(self, minimum):
        """Sets the minimum of this Schema.


        :param minimum: The minimum of this Schema.  # noqa: E501
        :type: float
        """

        self._minimum = minimum

    @property
    def exclusive_minimum(self):
        """Gets the exclusive_minimum of this Schema.  # noqa: E501


        :return: The exclusive_minimum of this Schema.  # noqa: E501
        :rtype: bool
        """
        return self._exclusive_minimum

    @exclusive_minimum.setter
    def exclusive_minimum(self, exclusive_minimum):
        """Sets the exclusive_minimum of this Schema.


        :param exclusive_minimum: The exclusive_minimum of this Schema.  # noqa: E501
        :type: bool
        """

        self._exclusive_minimum = exclusive_minimum

    @property
    def max_length(self):
        """Gets the max_length of this Schema.  # noqa: E501


        :return: The max_length of this Schema.  # noqa: E501
        :rtype: int
        """
        return self._max_length

    @max_length.setter
    def max_length(self, max_length):
        """Sets the max_length of this Schema.


        :param max_length: The max_length of this Schema.  # noqa: E501
        :type: int
        """

        self._max_length = max_length

    @property
    def min_length(self):
        """Gets the min_length of this Schema.  # noqa: E501


        :return: The min_length of this Schema.  # noqa: E501
        :rtype: int
        """
        return self._min_length

    @min_length.setter
    def min_length(self, min_length):
        """Sets the min_length of this Schema.


        :param min_length: The min_length of this Schema.  # noqa: E501
        :type: int
        """

        self._min_length = min_length

    @property
    def pattern(self):
        """Gets the pattern of this Schema.  # noqa: E501


        :return: The pattern of this Schema.  # noqa: E501
        :rtype: str
        """
        return self._pattern

    @pattern.setter
    def pattern(self, pattern):
        """Sets the pattern of this Schema.


        :param pattern: The pattern of this Schema.  # noqa: E501
        :type: str
        """

        self._pattern = pattern

    @property
    def max_items(self):
        """Gets the max_items of this Schema.  # noqa: E501


        :return: The max_items of this Schema.  # noqa: E501
        :rtype: int
        """
        return self._max_items

    @max_items.setter
    def max_items(self, max_items):
        """Sets the max_items of this Schema.


        :param max_items: The max_items of this Schema.  # noqa: E501
        :type: int
        """

        self._max_items = max_items

    @property
    def min_items(self):
        """Gets the min_items of this Schema.  # noqa: E501


        :return: The min_items of this Schema.  # noqa: E501
        :rtype: int
        """
        return self._min_items

    @min_items.setter
    def min_items(self, min_items):
        """Sets the min_items of this Schema.


        :param min_items: The min_items of this Schema.  # noqa: E501
        :type: int
        """

        self._min_items = min_items

    @property
    def unique_items(self):
        """Gets the unique_items of this Schema.  # noqa: E501


        :return: The unique_items of this Schema.  # noqa: E501
        :rtype: bool
        """
        return self._unique_items

    @unique_items.setter
    def unique_items(self, unique_items):
        """Sets the unique_items of this Schema.


        :param unique_items: The unique_items of this Schema.  # noqa: E501
        :type: bool
        """

        self._unique_items = unique_items

    @property
    def max_properties(self):
        """Gets the max_properties of this Schema.  # noqa: E501


        :return: The max_properties of this Schema.  # noqa: E501
        :rtype: int
        """
        return self._max_properties

    @max_properties.setter
    def max_properties(self, max_properties):
        """Sets the max_properties of this Schema.


        :param max_properties: The max_properties of this Schema.  # noqa: E501
        :type: int
        """

        self._max_properties = max_properties

    @property
    def min_properties(self):
        """Gets the min_properties of this Schema.  # noqa: E501


        :return: The min_properties of this Schema.  # noqa: E501
        :rtype: int
        """
        return self._min_properties

    @min_properties.setter
    def min_properties(self, min_properties):
        """Sets the min_properties of this Schema.


        :param min_properties: The min_properties of this Schema.  # noqa: E501
        :type: int
        """

        self._min_properties = min_properties

    @property
    def required(self):
        """Gets the required of this Schema.  # noqa: E501


        :return: The required of this Schema.  # noqa: E501
        :rtype: list[str]
        """
        return self._required

    @required.setter
    def required(self, required):
        """Sets the required of this Schema.


        :param required: The required of this Schema.  # noqa: E501
        :type: list[str]
        """

        self._required = required

    @property
    def type(self):
        """Gets the type of this Schema.  # noqa: E501


        :return: The type of this Schema.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Schema.


        :param type: The type of this Schema.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def _not(self):
        """Gets the _not of this Schema.  # noqa: E501


        :return: The _not of this Schema.  # noqa: E501
        :rtype: Schema
        """
        return self.__not

    @_not.setter
    def _not(self, _not):
        """Sets the _not of this Schema.


        :param _not: The _not of this Schema.  # noqa: E501
        :type: Schema
        """

        self.__not = _not

    @property
    def properties(self):
        """Gets the properties of this Schema.  # noqa: E501


        :return: The properties of this Schema.  # noqa: E501
        :rtype: dict(str, Schema)
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this Schema.


        :param properties: The properties of this Schema.  # noqa: E501
        :type: dict(str, Schema)
        """

        self._properties = properties

    @property
    def default(self):
        """Gets the default of this Schema.  # noqa: E501


        :return: The default of this Schema.  # noqa: E501
        :rtype: object
        """
        return self._default

    @default.setter
    def default(self, default):
        """Sets the default of this Schema.


        :param default: The default of this Schema.  # noqa: E501
        :type: object
        """

        self._default = default

    @property
    def description(self):
        """Gets the description of this Schema.  # noqa: E501


        :return: The description of this Schema.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Schema.


        :param description: The description of this Schema.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def format(self):
        """Gets the format of this Schema.  # noqa: E501


        :return: The format of this Schema.  # noqa: E501
        :rtype: str
        """
        return self._format

    @format.setter
    def format(self, format):
        """Sets the format of this Schema.


        :param format: The format of this Schema.  # noqa: E501
        :type: str
        """

        self._format = format

    @property
    def getref(self):
        """Gets the getref of this Schema.  # noqa: E501


        :return: The getref of this Schema.  # noqa: E501
        :rtype: str
        """
        return self._getref

    @getref.setter
    def getref(self, getref):
        """Sets the getref of this Schema.


        :param getref: The getref of this Schema.  # noqa: E501
        :type: str
        """

        self._getref = getref

    @property
    def nullable(self):
        """Gets the nullable of this Schema.  # noqa: E501


        :return: The nullable of this Schema.  # noqa: E501
        :rtype: bool
        """
        return self._nullable

    @nullable.setter
    def nullable(self, nullable):
        """Sets the nullable of this Schema.


        :param nullable: The nullable of this Schema.  # noqa: E501
        :type: bool
        """

        self._nullable = nullable

    @property
    def read_only(self):
        """Gets the read_only of this Schema.  # noqa: E501


        :return: The read_only of this Schema.  # noqa: E501
        :rtype: bool
        """
        return self._read_only

    @read_only.setter
    def read_only(self, read_only):
        """Sets the read_only of this Schema.


        :param read_only: The read_only of this Schema.  # noqa: E501
        :type: bool
        """

        self._read_only = read_only

    @property
    def write_only(self):
        """Gets the write_only of this Schema.  # noqa: E501


        :return: The write_only of this Schema.  # noqa: E501
        :rtype: bool
        """
        return self._write_only

    @write_only.setter
    def write_only(self, write_only):
        """Sets the write_only of this Schema.


        :param write_only: The write_only of this Schema.  # noqa: E501
        :type: bool
        """

        self._write_only = write_only

    @property
    def external_docs(self):
        """Gets the external_docs of this Schema.  # noqa: E501


        :return: The external_docs of this Schema.  # noqa: E501
        :rtype: ExternalDocumentation
        """
        return self._external_docs

    @external_docs.setter
    def external_docs(self, external_docs):
        """Sets the external_docs of this Schema.


        :param external_docs: The external_docs of this Schema.  # noqa: E501
        :type: ExternalDocumentation
        """

        self._external_docs = external_docs

    @property
    def deprecated(self):
        """Gets the deprecated of this Schema.  # noqa: E501


        :return: The deprecated of this Schema.  # noqa: E501
        :rtype: bool
        """
        return self._deprecated

    @deprecated.setter
    def deprecated(self, deprecated):
        """Sets the deprecated of this Schema.


        :param deprecated: The deprecated of this Schema.  # noqa: E501
        :type: bool
        """

        self._deprecated = deprecated

    @property
    def xml(self):
        """Gets the xml of this Schema.  # noqa: E501


        :return: The xml of this Schema.  # noqa: E501
        :rtype: XML
        """
        return self._xml

    @xml.setter
    def xml(self, xml):
        """Sets the xml of this Schema.


        :param xml: The xml of this Schema.  # noqa: E501
        :type: XML
        """

        self._xml = xml

    @property
    def extensions(self):
        """Gets the extensions of this Schema.  # noqa: E501


        :return: The extensions of this Schema.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._extensions

    @extensions.setter
    def extensions(self, extensions):
        """Sets the extensions of this Schema.


        :param extensions: The extensions of this Schema.  # noqa: E501
        :type: dict(str, object)
        """

        self._extensions = extensions

    @property
    def discriminator(self):
        """Gets the discriminator of this Schema.  # noqa: E501


        :return: The discriminator of this Schema.  # noqa: E501
        :rtype: Discriminator
        """
        return self._discriminator

    @discriminator.setter
    def discriminator(self, discriminator):
        """Sets the discriminator of this Schema.


        :param discriminator: The discriminator of this Schema.  # noqa: E501
        :type: Discriminator
        """

        self._discriminator = discriminator

    @property
    def enum(self):
        """Gets the enum of this Schema.  # noqa: E501


        :return: The enum of this Schema.  # noqa: E501
        :rtype: list[object]
        """
        return self._enum

    @enum.setter
    def enum(self, enum):
        """Sets the enum of this Schema.


        :param enum: The enum of this Schema.  # noqa: E501
        :type: list[object]
        """

        self._enum = enum

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Schema):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTDeviceInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'mobile': 'bool',
        'description': 'str',
        'version': 'BTUserAgentVersion',
        'client_type': 'str',
        'device_name': 'str',
        'operating_system': 'str',
        'device_type': 'str',
        'browser': 'str',
        'manufacturer': 'str'
    }

    attribute_map = {
        'mobile': 'mobile',
        'description': 'description',
        'version': 'version',
        'client_type': 'clientType',
        'device_name': 'deviceName',
        'operating_system': 'operatingSystem',
        'device_type': 'deviceType',
        'browser': 'browser',
        'manufacturer': 'manufacturer'
    }

    def __init__(self, mobile=None, description=None, version=None, client_type=None, device_name=None, operating_system=None, device_type=None, browser=None, manufacturer=None):  # noqa: E501
        """BTDeviceInfo - a model defined in OpenAPI"""  # noqa: E501

        self._mobile = None
        self._description = None
        self._version = None
        self._client_type = None
        self._device_name = None
        self._operating_system = None
        self._device_type = None
        self._browser = None
        self._manufacturer = None
        self.discriminator = None

        if mobile is not None:
            self.mobile = mobile
        if description is not None:
            self.description = description
        if version is not None:
            self.version = version
        if client_type is not None:
            self.client_type = client_type
        if device_name is not None:
            self.device_name = device_name
        if operating_system is not None:
            self.operating_system = operating_system
        if device_type is not None:
            self.device_type = device_type
        if browser is not None:
            self.browser = browser
        if manufacturer is not None:
            self.manufacturer = manufacturer

    @property
    def mobile(self):
        """Gets the mobile of this BTDeviceInfo.  # noqa: E501


        :return: The mobile of this BTDeviceInfo.  # noqa: E501
        :rtype: bool
        """
        return self._mobile

    @mobile.setter
    def mobile(self, mobile):
        """Sets the mobile of this BTDeviceInfo.


        :param mobile: The mobile of this BTDeviceInfo.  # noqa: E501
        :type: bool
        """

        self._mobile = mobile

    @property
    def description(self):
        """Gets the description of this BTDeviceInfo.  # noqa: E501


        :return: The description of this BTDeviceInfo.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BTDeviceInfo.


        :param description: The description of this BTDeviceInfo.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def version(self):
        """Gets the version of this BTDeviceInfo.  # noqa: E501


        :return: The version of this BTDeviceInfo.  # noqa: E501
        :rtype: BTUserAgentVersion
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this BTDeviceInfo.


        :param version: The version of this BTDeviceInfo.  # noqa: E501
        :type: BTUserAgentVersion
        """

        self._version = version

    @property
    def client_type(self):
        """Gets the client_type of this BTDeviceInfo.  # noqa: E501


        :return: The client_type of this BTDeviceInfo.  # noqa: E501
        :rtype: str
        """
        return self._client_type

    @client_type.setter
    def client_type(self, client_type):
        """Sets the client_type of this BTDeviceInfo.


        :param client_type: The client_type of this BTDeviceInfo.  # noqa: E501
        :type: str
        """
        allowed_values = ["UNKNOWN", "BROWSER", "IOS", "ANDROID", "MAGIC_LEAP"]  # noqa: E501
        if client_type not in allowed_values:
            raise ValueError(
                "Invalid value for `client_type` ({0}), must be one of {1}"  # noqa: E501
                .format(client_type, allowed_values)
            )

        self._client_type = client_type

    @property
    def device_name(self):
        """Gets the device_name of this BTDeviceInfo.  # noqa: E501


        :return: The device_name of this BTDeviceInfo.  # noqa: E501
        :rtype: str
        """
        return self._device_name

    @device_name.setter
    def device_name(self, device_name):
        """Sets the device_name of this BTDeviceInfo.


        :param device_name: The device_name of this BTDeviceInfo.  # noqa: E501
        :type: str
        """

        self._device_name = device_name

    @property
    def operating_system(self):
        """Gets the operating_system of this BTDeviceInfo.  # noqa: E501


        :return: The operating_system of this BTDeviceInfo.  # noqa: E501
        :rtype: str
        """
        return self._operating_system

    @operating_system.setter
    def operating_system(self, operating_system):
        """Sets the operating_system of this BTDeviceInfo.


        :param operating_system: The operating_system of this BTDeviceInfo.  # noqa: E501
        :type: str
        """
        allowed_values = ["WINDOWS", "WINDOWS_10", "WINDOWS_81", "WINDOWS_8", "WINDOWS_7", "WINDOWS_VISTA", "WINDOWS_2000", "WINDOWS_XP", "WINDOWS_10_MOBILE", "WINDOWS_PHONE8_1", "WINDOWS_PHONE8", "WINDOWS_MOBILE7", "WINDOWS_MOBILE", "WINDOWS_98", "XBOX_OS", "ONSHAPE", "ONSHAPE_ANDROID", "ONSHAPE_ANDROID_7", "ONSHAPE_ANDROID_6", "ONSHAPE_ANDROID_5", "ONSHAPE_ANDROID_4", "ONSHAPE_ANDROID_TABLET", "ONSHAPE_ANDROID_7_TABLET", "ONSHAPE_ANDROID_6_TABLET", "ONSHAPE_ANDROID_5_TABLET", "ONSHAPE_ANDROID_4_TABLET", "ONSHAPE_IPHONE", "ONSHAPE_IPHONE_10", "ONSHAPE_IPHONE_9", "ONSHAPE_IPHONE_8_4", "ONSHAPE_IPHONE_8_3", "ONSHAPE_IPHONE_8_2", "ONSHAPE_IPHONE_8_1", "ONSHAPE_IPHONE_8", "ONSHAPE_IPHONE_7", "ONSHAPE_IPAD", "ONSHAPE_IPAD_10", "ONSHAPE_IPAD_9", "ONSHAPE_IPAD_8_4", "ONSHAPE_IPAD_8_3", "ONSHAPE_IPAD_8_2", "ONSHAPE_IPAD_8_1", "ONSHAPE_IPAD_8", "ONSHAPE_IPAD_7", "ONSHAPE_IPOD", "ONSHAPE_IPOD_10", "ONSHAPE_IPOD_9", "ONSHAPE_IPOD_8_4", "ONSHAPE_IPOD_8_3", "ONSHAPE_IPOD_8_2", "ONSHAPE_IPOD_8_1", "ONSHAPE_IPOD_8", "ONSHAPE_IPOD_7", "ANDROID", "ANDROID7", "ANDROID7_TABLET", "ANDROID6", "ANDROID6_TABLET", "ANDROID5", "ANDROID5_TABLET", "ANDROID4", "ANDROID4_TABLET", "ANDROID4_WEARABLE", "ANDROID3_TABLET", "ANDROID2", "ANDROID2_TABLET", "ANDROID1", "ANDROID_MOBILE", "ANDROID_TABLET", "CHROME_OS", "WEBOS", "PALM", "MEEGO", "IOS", "iOS10_IPHONE", "iOS9_IPHONE", "iOS8_4_IPHONE", "iOS8_3_IPHONE", "iOS8_2_IPHONE", "iOS8_1_IPHONE", "iOS8_IPHONE", "iOS7_IPHONE", "iOS6_IPHONE", "iOS5_IPHONE", "iOS4_IPHONE", "MAC_OS_X_IPAD", "iOS10_IPAD", "iOS9_IPAD", "iOS8_4_IPAD", "iOS8_3_IPAD", "iOS8_2_IPAD", "iOS8_1_IPAD", "iOS8_IPAD", "iOS7_IPAD", "iOS6_IPAD", "MAC_OS_X_IPHONE", "MAC_OS_X_IPOD", "MAC_OS_X", "MAC_OS", "MAEMO", "BADA", "GOOGLE_TV", "KINDLE", "KINDLE3", "KINDLE2", "LINUX", "UBUNTU", "UBUNTU_TOUCH_MOBILE", "SYMBIAN", "SYMBIAN9", "SYMBIAN8", "SYMBIAN7", "SYMBIAN6", "SERIES40", "SONY_ERICSSON", "SUN_OS", "PSP", "WII", "BLACKBERRY", "BLACKBERRY7", "BLACKBERRY6", "BLACKBERRY_TABLET", "ROKU", "PROXY", "UNKNOWN_MOBILE", "UNKNOWN_TABLET", "UNKNOWN"]  # noqa: E501
        if operating_system not in allowed_values:
            raise ValueError(
                "Invalid value for `operating_system` ({0}), must be one of {1}"  # noqa: E501
                .format(operating_system, allowed_values)
            )

        self._operating_system = operating_system

    @property
    def device_type(self):
        """Gets the device_type of this BTDeviceInfo.  # noqa: E501


        :return: The device_type of this BTDeviceInfo.  # noqa: E501
        :rtype: str
        """
        return self._device_type

    @device_type.setter
    def device_type(self, device_type):
        """Sets the device_type of this BTDeviceInfo.


        :param device_type: The device_type of this BTDeviceInfo.  # noqa: E501
        :type: str
        """

        self._device_type = device_type

    @property
    def browser(self):
        """Gets the browser of this BTDeviceInfo.  # noqa: E501


        :return: The browser of this BTDeviceInfo.  # noqa: E501
        :rtype: str
        """
        return self._browser

    @browser.setter
    def browser(self, browser):
        """Sets the browser of this BTDeviceInfo.


        :param browser: The browser of this BTDeviceInfo.  # noqa: E501
        :type: str
        """
        allowed_values = ["OUTLOOK", "OUTLOOK2007", "OUTLOOK2013", "OUTLOOK2010", "IE", "OUTLOOK_EXPRESS7", "IEMOBILE11", "IEMOBILE10", "IEMOBILE9", "IEMOBILE7", "IEMOBILE6", "IE_XBOX", "IE11", "IE10", "IE9", "IE8", "IE7", "IE6", "IE5_5", "IE5", "EDGE", "EDGE12", "EDGE_MOBILE12", "CHROME", "CHROME_MOBILE", "CHROME46", "CHROME45", "CHROME44", "CHROME43", "CHROME42", "CHROME41", "CHROME40", "CHROME39", "CHROME38", "CHROME37", "CHROME36", "CHROME35", "CHROME34", "CHROME33", "CHROME32", "CHROME31", "CHROME30", "CHROME29", "CHROME28", "CHROME27", "CHROME26", "CHROME25", "CHROME24", "CHROME23", "CHROME22", "CHROME21", "CHROME20", "CHROME19", "CHROME18", "CHROME17", "CHROME16", "CHROME15", "CHROME14", "CHROME13", "CHROME12", "CHROME11", "CHROME10", "CHROME9", "CHROME8", "OMNIWEB", "SAFARI", "BLACKBERRY10", "MOBILE_SAFARI", "SILK", "SAFARI9", "SAFARI8", "SAFARI7", "SAFARI6", "SAFARI5", "SAFARI4", "COAST", "COAST1", "OPERA", "OPERA_MOBILE", "OPERA_MINI", "OPERA34", "OPERA33", "OPERA32", "OPERA31", "OPERA30", "OPERA29", "OPERA28", "OPERA27", "OPERA26", "OPERA25", "OPERA24", "OPERA23", "OPERA20", "OPERA19", "OPERA18", "OPERA17", "OPERA16", "OPERA15", "OPERA12", "OPERA11", "OPERA10", "OPERA9", "KONQUEROR", "DOLFIN2", "APPLE_WEB_KIT", "APPLE_ITUNES", "APPLE_APPSTORE", "ADOBE_AIR", "LOTUS_NOTES", "CAMINO", "CAMINO2", "FLOCK", "FIREFOX", "FIREFOX3MOBILE", "FIREFOX_MOBILE", "FIREFOX_MOBILE23", "FIREFOX42", "FIREFOX41", "FIREFOX40", "FIREFOX39", "FIREFOX38", "FIREFOX37", "FIREFOX36", "FIREFOX35", "FIREFOX34", "FIREFOX33", "FIREFOX32", "FIREFOX31", "FIREFOX30", "FIREFOX29", "FIREFOX28", "FIREFOX27", "FIREFOX26", "FIREFOX25", "FIREFOX24", "FIREFOX23", "FIREFOX22", "FIREFOX21", "FIREFOX20", "FIREFOX19", "FIREFOX18", "FIREFOX17", "FIREFOX16", "FIREFOX15", "FIREFOX14", "FIREFOX13", "FIREFOX12", "FIREFOX11", "FIREFOX10", "FIREFOX9", "FIREFOX8", "FIREFOX7", "FIREFOX6", "FIREFOX5", "FIREFOX4", "FIREFOX3", "FIREFOX2", "FIREFOX1_5", "THUNDERBIRD", "THUNDERBIRD12", "THUNDERBIRD11", "THUNDERBIRD10", "THUNDERBIRD8", "THUNDERBIRD7", "THUNDERBIRD6", "THUNDERBIRD3", "THUNDERBIRD2", "VIVALDI", "ONSHAPE", "ONSHAPE_IPAD", "ONSHAPE_IPHONE", "ONSHAPE_ANDROID", "SEAMONKEY", "BOT", "BOT_MOBILE", "MOZILLA", "CFNETWORK", "EUDORA", "POCOMAIL", "THEBAT", "NETFRONT", "EVOLUTION", "LYNX", "DOWNLOAD", "UNKNOWN", "APPLE_MAIL"]  # noqa: E501
        if browser not in allowed_values:
            raise ValueError(
                "Invalid value for `browser` ({0}), must be one of {1}"  # noqa: E501
                .format(browser, allowed_values)
            )

        self._browser = browser

    @property
    def manufacturer(self):
        """Gets the manufacturer of this BTDeviceInfo.  # noqa: E501


        :return: The manufacturer of this BTDeviceInfo.  # noqa: E501
        :rtype: str
        """
        return self._manufacturer

    @manufacturer.setter
    def manufacturer(self, manufacturer):
        """Sets the manufacturer of this BTDeviceInfo.


        :param manufacturer: The manufacturer of this BTDeviceInfo.  # noqa: E501
        :type: str
        """

        self._manufacturer = manufacturer

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTDeviceInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



import six

# Alphabetical!
def get_http_server():
    if six.PY2:
        from BaseHTTPServer import HTTPServer
        from SimpleHTTPServer import SimpleHTTPRequestHandler as HTTPHandler
    else:
        from http.server import HTTPServer
        from http.server import BaseHTTPRequestHandler as HTTPHandler
    return HTTPServer, HTTPHandler

def get_parse():
    if six.PY2:
        from urlparse import urlparse as parse
    else:
        from urllib.parse import urlparse as parse
    return parse

def get_sendable():
    if six.PY2:
        def sendable(s):
            return s
    else:
        def sendable(s):
            return bytes(s, 'UTF-8')
    return sendable

def get_unquote():
    if six.PY2:
        from urllib import unquote as unquote
    else:
        from urllib.parse import unquote as unquote
    return unquote

# Alphabetical!
HTTPServer, HTTPHandler = get_http_server()
parse=get_parse()
sendable=get_sendable()
unquote=get_unquote()



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTStandardContentCustomParameterDefinition(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'BTStandardContentCustomParameterDefinitionId',
        'name': 'str',
        'description': 'str',
        'created_by': 'str',
        'created_at': 'datetime',
        'modified_by': 'str',
        'modified_at': 'datetime',
        'parameter_type': 'int',
        'parameter_value': 'str',
        'is_driving_configuration': 'bool',
        'parameter_link_type': 'int',
        'new': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'description': 'description',
        'created_by': 'createdBy',
        'created_at': 'createdAt',
        'modified_by': 'modifiedBy',
        'modified_at': 'modifiedAt',
        'parameter_type': 'parameterType',
        'parameter_value': 'parameterValue',
        'is_driving_configuration': 'isDrivingConfiguration',
        'parameter_link_type': 'parameterLinkType',
        'new': 'new'
    }

    def __init__(self, id=None, name=None, description=None, created_by=None, created_at=None, modified_by=None, modified_at=None, parameter_type=None, parameter_value=None, is_driving_configuration=None, parameter_link_type=None, new=None):  # noqa: E501
        """BTStandardContentCustomParameterDefinition - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._name = None
        self._description = None
        self._created_by = None
        self._created_at = None
        self._modified_by = None
        self._modified_at = None
        self._parameter_type = None
        self._parameter_value = None
        self._is_driving_configuration = None
        self._parameter_link_type = None
        self._new = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if created_by is not None:
            self.created_by = created_by
        if created_at is not None:
            self.created_at = created_at
        if modified_by is not None:
            self.modified_by = modified_by
        if modified_at is not None:
            self.modified_at = modified_at
        if parameter_type is not None:
            self.parameter_type = parameter_type
        if parameter_value is not None:
            self.parameter_value = parameter_value
        if is_driving_configuration is not None:
            self.is_driving_configuration = is_driving_configuration
        if parameter_link_type is not None:
            self.parameter_link_type = parameter_link_type
        if new is not None:
            self.new = new

    @property
    def id(self):
        """Gets the id of this BTStandardContentCustomParameterDefinition.  # noqa: E501


        :return: The id of this BTStandardContentCustomParameterDefinition.  # noqa: E501
        :rtype: BTStandardContentCustomParameterDefinitionId
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BTStandardContentCustomParameterDefinition.


        :param id: The id of this BTStandardContentCustomParameterDefinition.  # noqa: E501
        :type: BTStandardContentCustomParameterDefinitionId
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this BTStandardContentCustomParameterDefinition.  # noqa: E501


        :return: The name of this BTStandardContentCustomParameterDefinition.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTStandardContentCustomParameterDefinition.


        :param name: The name of this BTStandardContentCustomParameterDefinition.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this BTStandardContentCustomParameterDefinition.  # noqa: E501


        :return: The description of this BTStandardContentCustomParameterDefinition.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BTStandardContentCustomParameterDefinition.


        :param description: The description of this BTStandardContentCustomParameterDefinition.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def created_by(self):
        """Gets the created_by of this BTStandardContentCustomParameterDefinition.  # noqa: E501


        :return: The created_by of this BTStandardContentCustomParameterDefinition.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this BTStandardContentCustomParameterDefinition.


        :param created_by: The created_by of this BTStandardContentCustomParameterDefinition.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def created_at(self):
        """Gets the created_at of this BTStandardContentCustomParameterDefinition.  # noqa: E501


        :return: The created_at of this BTStandardContentCustomParameterDefinition.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this BTStandardContentCustomParameterDefinition.


        :param created_at: The created_at of this BTStandardContentCustomParameterDefinition.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def modified_by(self):
        """Gets the modified_by of this BTStandardContentCustomParameterDefinition.  # noqa: E501


        :return: The modified_by of this BTStandardContentCustomParameterDefinition.  # noqa: E501
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """Sets the modified_by of this BTStandardContentCustomParameterDefinition.


        :param modified_by: The modified_by of this BTStandardContentCustomParameterDefinition.  # noqa: E501
        :type: str
        """

        self._modified_by = modified_by

    @property
    def modified_at(self):
        """Gets the modified_at of this BTStandardContentCustomParameterDefinition.  # noqa: E501


        :return: The modified_at of this BTStandardContentCustomParameterDefinition.  # noqa: E501
        :rtype: datetime
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this BTStandardContentCustomParameterDefinition.


        :param modified_at: The modified_at of this BTStandardContentCustomParameterDefinition.  # noqa: E501
        :type: datetime
        """

        self._modified_at = modified_at

    @property
    def parameter_type(self):
        """Gets the parameter_type of this BTStandardContentCustomParameterDefinition.  # noqa: E501


        :return: The parameter_type of this BTStandardContentCustomParameterDefinition.  # noqa: E501
        :rtype: int
        """
        return self._parameter_type

    @parameter_type.setter
    def parameter_type(self, parameter_type):
        """Sets the parameter_type of this BTStandardContentCustomParameterDefinition.


        :param parameter_type: The parameter_type of this BTStandardContentCustomParameterDefinition.  # noqa: E501
        :type: int
        """

        self._parameter_type = parameter_type

    @property
    def parameter_value(self):
        """Gets the parameter_value of this BTStandardContentCustomParameterDefinition.  # noqa: E501


        :return: The parameter_value of this BTStandardContentCustomParameterDefinition.  # noqa: E501
        :rtype: str
        """
        return self._parameter_value

    @parameter_value.setter
    def parameter_value(self, parameter_value):
        """Sets the parameter_value of this BTStandardContentCustomParameterDefinition.


        :param parameter_value: The parameter_value of this BTStandardContentCustomParameterDefinition.  # noqa: E501
        :type: str
        """

        self._parameter_value = parameter_value

    @property
    def is_driving_configuration(self):
        """Gets the is_driving_configuration of this BTStandardContentCustomParameterDefinition.  # noqa: E501


        :return: The is_driving_configuration of this BTStandardContentCustomParameterDefinition.  # noqa: E501
        :rtype: bool
        """
        return self._is_driving_configuration

    @is_driving_configuration.setter
    def is_driving_configuration(self, is_driving_configuration):
        """Sets the is_driving_configuration of this BTStandardContentCustomParameterDefinition.


        :param is_driving_configuration: The is_driving_configuration of this BTStandardContentCustomParameterDefinition.  # noqa: E501
        :type: bool
        """

        self._is_driving_configuration = is_driving_configuration

    @property
    def parameter_link_type(self):
        """Gets the parameter_link_type of this BTStandardContentCustomParameterDefinition.  # noqa: E501


        :return: The parameter_link_type of this BTStandardContentCustomParameterDefinition.  # noqa: E501
        :rtype: int
        """
        return self._parameter_link_type

    @parameter_link_type.setter
    def parameter_link_type(self, parameter_link_type):
        """Sets the parameter_link_type of this BTStandardContentCustomParameterDefinition.


        :param parameter_link_type: The parameter_link_type of this BTStandardContentCustomParameterDefinition.  # noqa: E501
        :type: int
        """

        self._parameter_link_type = parameter_link_type

    @property
    def new(self):
        """Gets the new of this BTStandardContentCustomParameterDefinition.  # noqa: E501


        :return: The new of this BTStandardContentCustomParameterDefinition.  # noqa: E501
        :rtype: bool
        """
        return self._new

    @new.setter
    def new(self, new):
        """Sets the new of this BTStandardContentCustomParameterDefinition.


        :param new: The new of this BTStandardContentCustomParameterDefinition.  # noqa: E501
        :type: bool
        """

        self._new = new

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTStandardContentCustomParameterDefinition):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
